package com.brilliance.swift;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoCreateManager;
import com.brilliance.swift.mx2mt.Mx2MtCreatorManager;
import com.brilliance.swift.mx2swiftdto.Mx2SwiftDtoCreatorManager;
import com.brilliance.swift.swiftdto2mt.SwiftDto2MtCreatorManager;
import com.brilliance.swift.swiftdto2mx.SwiftDto2MxCreatorManager;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.SwiftDto;
import com.prowidesoftware.swift.model.mx.AbstractMX;
import org.apache.commons.io.FileUtils;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;

import java.io.File;
import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Set;

public class SwiftTransfer {

    /**
     * SWIFTDTO transfer MT
     * @param file
     * @param fileOutputPath
     * @param extraMap
     * @return
     * @throws SwiftException
     */
    public static String swiftDto2Mt(File file, String fileOutputPath, Map<String, Object> extraMap) throws SwiftException {
        try {
            String gsonStr = FileUtils.readFileToString(file);
            SwiftDto swiftDto = SwiftDto.fromJson(gsonStr);
            return new SwiftDto2MtCreatorManager().swiftDto2Mt(swiftDto, fileOutputPath, extraMap);
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    public static String swiftDto2Mt(String gsonStr, String fileOutputPath, Map<String, Object> extraMap) throws SwiftException{
        SwiftDto swiftDto = SwiftDto.fromJson(gsonStr);
        return new SwiftDto2MtCreatorManager().swiftDto2Mt(swiftDto, fileOutputPath, extraMap);
    }

    /**
     * MT transfer SWIFTDTO
     * @param file
     * @param outPutFilePath
     * @param extraMap
     * @return
     * @throws SwiftException
     */
    public static SwiftDto mt2SwiftDto(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String mtStr = FileUtils.readFileToString(file);
            return new Mt2SwiftDtoCreateManager().convert(mtStr, outPutFilePath, extraMap);
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    public static SwiftDto mt2SwiftDto(String mtStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        return new Mt2SwiftDtoCreateManager().convert(mtStr, outPutFilePath, extraMap);
    }

    /**
     * MX transfer SWIFTDTO
     * @param file
     * @param outPutFilePath
     * @param extraMap
     * @return
     * @throws SwiftException
     */
    public static SwiftDto mx2SwiftDto(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String xmlStr = FileUtils.readFileToString(file);
            return new Mx2SwiftDtoCreatorManager().convert(xmlStr, outPutFilePath, extraMap);
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }

    }

    public static SwiftDto mx2SwiftDto(String xmlStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        return new Mx2SwiftDtoCreatorManager().convert(xmlStr, outPutFilePath, extraMap);
    }

    /**
     * SWIFTDTO transfer MX
     * @param file
     * @param fileOutputPath
     * @return
     * @throws SwiftException
     */
    public static String swiftDto2Mx(File file, String fileOutputPath) throws SwiftException {
        try {
            String gsonStr = FileUtils.readFileToString(file);
            SwiftDto swiftDto = SwiftDto.fromJson(gsonStr);
            return new SwiftDto2MxCreatorManager().swiftDto2Mx(swiftDto, fileOutputPath);
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    public static String swiftDto2Mx(String gsonStr, String fileOutputPath) throws SwiftException{
        SwiftDto swiftDto = SwiftDto.fromJson(gsonStr);
        return new SwiftDto2MxCreatorManager().swiftDto2Mx(swiftDto, fileOutputPath);
    }

    /**
     * MX TRANSFER MT
     */
    public static String mx2Mt(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String xmlStr = FileUtils.readFileToString(file);
            return mx2Mt(xmlStr, outPutFilePath, extraMap);
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }

    }

    public static String mx2Mt(String xmlStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        return new Mx2MtCreatorManager().mx2Mt(xmlStr, outPutFilePath, extraMap);
    }

    /**
     * MT TRANSFER MX
     */
    public static String mt2Mx(File file, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        try{
            String mtStr = FileUtils.readFileToString(file);
            SwiftDto swiftDto = new Mt2SwiftDtoCreateManager().convert(mtStr, outPutFilePath, extraMap);
            return new SwiftDto2MxCreatorManager().swiftDto2Mx(swiftDto, outPutFilePath);
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    public static String mt2Mx(String mtStr, String outPutFilePath, Map<String, Object> extraMap) throws SwiftException {
        SwiftDto swiftDto = new Mt2SwiftDtoCreateManager().convert(mtStr, outPutFilePath, extraMap);
        return new SwiftDto2MxCreatorManager().swiftDto2Mx(swiftDto, outPutFilePath);
    }

    /**
     * swift xml输出mt 相关的map
     * 用于邮储版本
     * @param xmlStr
     * @param extraMap
     * @return
     * @throws SwiftException
     */
    public static Map<String, String> mx2MtMap(String xmlStr, Map<String, Object> extraMap) throws SwiftException {
        try {
            String mtStr = new Mx2MtCreatorManager().mx2Mt(xmlStr, null, extraMap);
            Map<String, String> maps = MessageReader.getSwfMsgInfoViaMsg(mtStr);
            AbstractMX abstractMx = AbstractMX.parse(xmlStr);
            if (abstractMx != null) {
                String messageType = abstractMx.getMxId().id();
                maps.put("xty", messageType);//ISO20022类型
                if (messageType.startsWith("pacs.008.001") || messageType.startsWith("pacs.009.001")) {
                    Document document = DocumentHelper.parseText(xmlStr);
                    Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
                    String bodyParentElementName = parentElementMaps.get("CdtTrfTxInf");
                    String endToEndId = XmlUtil.getXmlNodeValue(document, bodyParentElementName + ".CdtTrfTxInf.PmtId.EndToEndId");
                    if (StringUtil.isNotEmpty(endToEndId)) {
                        maps.put("endToEndId", endToEndId);
                    }
                }
            }
            return maps;
        } catch (DocumentException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }

    }

    /**
     * 将MX xml转换成gson 字符串
     * @param xmlStr
     * @return
     */
    public static String mx2Gson(String xmlStr) {
        if (StringUtil.isEmpty(xmlStr)) return null;
        AbstractMX abstractMX = AbstractMX.parse(xmlStr);
        String gsonStr = abstractMX.toJson();
        return gsonStr;
    }

    /**
     * 将MX xml转换成Map<String, String>
     * @param xmlStr
     * @return
     */
    public static Map<String, String> mx2Map(String xmlStr) {
        if (StringUtil.isEmpty(xmlStr)) return null;
        Map<String, String> maps = new LinkedHashMap<>();
        AbstractMX abstractMX = AbstractMX.parse(xmlStr);
        String gsonStr = abstractMX.toJson();
        Map<String, Object> mxGsonMaps = (Map<String, Object>) JSON.parseObject(gsonStr);
        parseMxGsonMap(maps, mxGsonMaps, null);
        return maps;
    }

    /**
     * 把mxGsonMaps解析成Map<String, String>，回调函数然后拼接前缀
     * @param maps
     * @param mxGsonMaps
     * @param prefix
     */
    public static void parseMxGsonMap(Map<String, String> maps, Map<String, Object> mxGsonMaps, String prefix) {
        Set<String> keys = mxGsonMaps.keySet();
        for (String key : keys) {
            Object object = (Object)mxGsonMaps.get(key);
            if (object == null) continue;
            if (object instanceof JSONArray) {
                if (StringUtil.isEmpty(prefix)) {
                    parseMxGsonArray(maps, (JSONArray)object, key);
                } else {
                    parseMxGsonArray(maps, (JSONArray)object, prefix + "." + key);
                }
            } else if (object instanceof JSONObject) {
                if (StringUtil.isEmpty(prefix)) {
                    parseMxGsonMap(maps, (Map<String, Object>)object, key);
                } else {
                    parseMxGsonMap(maps, (Map<String, Object>)object, prefix + "." + key);
                }
            } else {
                if (StringUtil.isEmpty(prefix)) {
                    maps.put(key, String.valueOf(object));
                } else {
                    maps.put(prefix + "." + key, String.valueOf(object));
                }
            }
        }
    }

    /**
     * jsonArray 是json数组格式 回调函数
     * 如果长度只有1，那么就不需要下标
     * 否则需要下标(0) (1) (2) (3)
     * @param maps
     * @param jsonArray
     * @param prefix
     */
    public static void parseMxGsonArray(Map<String, String> maps, JSONArray jsonArray, String prefix) {
        Object[] jsonArrays = jsonArray.toArray();
        if (jsonArrays.length == 1) {
            Object object = jsonArrays[0];
            if (object instanceof JSONArray) {
                parseMxGsonArray(maps, (JSONArray)object, prefix);
            } else if (object instanceof JSONObject) {
                parseMxGsonMap(maps, (Map<String, Object>)object, prefix);
            } else {
                maps.put(prefix, String.valueOf(object));
            }
        } else {
            for (int i=0; i<jsonArrays.length; i++) {
                Object object = jsonArrays[i];
                if (object instanceof JSONArray) {
                    parseMxGsonArray(maps, (JSONArray)object, prefix+"("+i+")");
                } else if (object instanceof JSONObject) {
                    parseMxGsonMap(maps, (Map<String, Object>)object, prefix+"("+i+")");
                } else {
                    maps.put(prefix+"("+i+")", String.valueOf(object));
                }
            }
        }
    }

}
