package com.brilliance.swift.context;

import java.util.List;

/**
 * The container to store objects
 * @author chengzhuoshen
 */
public interface Context {
    /**
     * To get the stored object
     * @param identifier
     *        - String
     * @return Object
     */
    Object get(String identifier);
    /**
     * To get the stored object
     * @param identifier
     *        - String
     * @param returnNull
     *        - boolean
     * @return Object
     */
    Object get(String identifier, boolean returnNull);

    /**
     * To get the stored object by class name
     * @param cls
     *        - Class
     * @return Object
     */
    <T> T get(Class<T> cls);

    /**
     * To set object
     * @param identifier
     *        - String
     * @param object
     *        - Object
     */
    void set(String identifier, Object object);

    /**
     * To set object with specified class <u>cls</u> name as identifier
     * @param cls
     *        - Class
     * @param object
     *        - Object
     */
    void set(Class<?> cls, Object object);

    /**
     * To set object with its actual class name as identifier
     * @param object
     *        - Object
     */
    void set(Object object);

    /**
     * To get a list of object with specified class type <u>objType</u>.
     * @param objType
     *        - Class
     * @return List
     */
    <T> List<T> getList(Class<T> objType);

    /**
     * To get a list of object with specified class type <u>objType</u>.
     * @param objType
     *        - Class
     * @param returnNull
     *        - boolean
     * @return List
     */
    <T> List<T> getList(Class<T> objType, boolean returnNull);

    /**
     * To set a list of object with specified class type <u>objType</u>.
     * @param objType
     *        - Class
     * @param objects
     *        - List
     */
    void setList(Class<?> objType, List<?> objects);

    /**
     * To set a context delegate which has held objects
     * @param delegate
     *        - Context
     * @return Context
     */
    Context setDelegate(Context delegate);

    /**
     * To clear all stored objects.
     */
    void clear();

    /**
     * To remove object
     * @param identifier
     *        the object identifier in the context, refer to
     */
    void remove(String identifier);
}
