package com.brilliance.swift.mt2SwiftDto;

import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.SwiftTransferUtil;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.mt.AbstractMT;

public abstract class AbstractMt2SwiftDtoParseFields implements Mt2SwiftDtoParseFields {

    protected Mt2SwiftDtoContext context;

    public Mt2SwiftDtoContext getContext() {
        return context;
    }

    public void setContext(Mt2SwiftDtoContext context) {
        this.context = context;
    }

    public ClearingSystemMemberCode getClsSysMemberByDesc(String desc) {
        ClearingSystemMemberCode code = null;
        ClearingSystemMemberCode[] values = ClearingSystemMemberCode.values();
        for (ClearingSystemMemberCode tmpCode : values) {
            if (tmpCode.desc().equals(desc)) {
                code = tmpCode;
                break;
            }
        }
        return code;
    }

    public CategoryPurposeCode getCategoryPurposeByCode(String value) {
        CategoryPurposeCode code = null;
        CategoryPurposeCode[] values = CategoryPurposeCode.values();
        for (CategoryPurposeCode tmpCode : values) {
            if (value.equals(tmpCode.value())) {
                code = tmpCode;
                break;
            }
        }
        return code;
    }

    public ExternalCreditorAgentInstructionCode getExternalCreditorAgentInstructionByCode(String value) {
        ExternalCreditorAgentInstructionCode code = null;
        ExternalCreditorAgentInstructionCode[] values = ExternalCreditorAgentInstructionCode.values();
        for (ExternalCreditorAgentInstructionCode tmpCode : values) {
            if (value.equals(tmpCode.value())) {
                code = tmpCode;
                break;
            }
        }
        return code;
    }

    protected PartyAccount buildPartyAccount(String account) {
        PartyAccount partyAcct = null;
        if (StringUtil.isNotEmpty(account)) {
            partyAcct = new PartyAccount();
            if (account.length() > 4 && account.startsWith("//")) {
                if ("CH".equals(account.substring(2, 4))) {
                    AcctSchemeType acctSchemeType = new AcctSchemeType();
                    acctSchemeType.setCode(AcctSehemeTypeCode.CUID);
                    partyAcct.setAcctSehemeType(acctSchemeType);
                    partyAcct.setAccount(account.substring(4));
                } else {
                    partyAcct.setAccount(account.substring(2));
                }
            } else {
                if (account.length() > 3 && (account.startsWith("/C/") || account.startsWith("/D/"))) {
                    account = account.substring(3);
                } else {
                    if (account.startsWith("/")) {
                        account = account.substring(1);
                    }
                }
                if (SwiftTransferUtil.checkIbanAccount(account)) {
                    partyAcct.setIbanAcct(account);
                } else {
                    partyAcct.setAccount(account);
                }
            }
        }
        return partyAcct;
    }

    protected PartyDto buildPartyAccount(PartyDto partyDto, String account) {
        if (StringUtil.isNotEmpty(account)) {
            if (account.length() > 4 && account.startsWith("//")) {
                ClearingSystemMemberCode code = getClsSysMemberByDesc(account.substring(2, 4));
                if (code != null) {
                    ClearingSystemMember clrSysMember = new ClearingSystemMember();
                    clrSysMember.setCode(code.value());
                    clrSysMember.setId(account.substring(4));
                    partyDto.setClrSysMmb(clrSysMember);
                } else {
                    PartyAccount partyAcct = new PartyAccount();
                    if ("CH".equals(account.substring(2, 4))) {
                        AcctSchemeType acctSchemeType = new AcctSchemeType();
                        acctSchemeType.setCode(AcctSehemeTypeCode.CUID);
                        partyAcct.setAcctSehemeType(acctSchemeType);
                        partyAcct.setAccount(account.substring(4));
                    } else {
                        partyAcct.setAccount(account.substring(2));
                    }
                    partyDto.setPartyAcct(partyAcct);
                }
            } else {
                if (account.length() > 3 && (account.startsWith("/C/") || account.startsWith("/D/"))) {
                    account = account.substring(3);
                } else {
                    account = account.substring(1);
                }
                PartyAccount partyAcct = new PartyAccount();
                if (SwiftTransferUtil.checkIbanAccount(account)) {
                    partyAcct.setIbanAcct(account);
                } else {
                    partyAcct.setAccount(account);
                }
                partyDto.setPartyAcct(partyAcct);
            }
        }
        return partyDto;
    }

    protected boolean isCov() {
        AbstractMT abstractMT = context.get(AbstractMT.class);
        return abstractMT.getSwiftMessage().isCOV();
    }
}
