package com.brilliance.swift.mt2SwiftDto.camt053001;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoCreator;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoContextIdentifier;
import com.brilliance.swift.mt2SwiftDto.Mt2SwiftDtoParseFields;
import com.brilliance.swift.mt2SwiftDto.camt053001.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.common.TransactionReference;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * @author zh
 * @create 2022-04-24 17:06
 */
public class Mt2SwiftDtoPCamt053001Creator extends AbstractMt2SwiftDtoCreator {
    @Override
    public void preProcess() throws SwiftException {
        SwiftHeader swiftHeader = buildSwiftHeader();
        swiftHeader.setMessageDefId("camt.053.001.09");
        swiftHeader.setBusinessService("swift.cbprplus.02");
        swiftHeader.setMessageType("camt.053.001");
        swiftHeader.setVersion("08");
        BankToCustomerStatement bankToCustomerStatement = new BankToCustomerStatement();
        bankToCustomerStatement.setSwiftHeader(swiftHeader);
        TransactionReference txnRef = buildTxnRef();
        bankToCustomerStatement.setTxnRef(txnRef);
        context.set(bankToCustomerStatement);
    }
    @Override
    public List<Mt2SwiftDtoParseFields> getParseFieldsList() throws SwiftException {
        List<Mt2SwiftDtoParseFields> list = new ArrayList<>();
        list.add(new Camt053001Parse20Field());
        list.add(new Camt053001Parse21Field());
        list.add(new Camt053001Parse25aField());
        list.add(new Camt053001Parse28CField());
        list.add(new Camt053001Parse60aField());
        list.add(new Camt053001Parse61Field());
        list.add(new Camt053001Parse62aField());
        list.add(new Camt053001Parse64Field());
        list.add(new Camt053001Parse65Field());
        list.add(new Camt053001Parse86Field());
        return list;
    }

    @Override
    public void postProcess() throws SwiftException {
        try {
            String outputFilePath = (String)context.get(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OUTPUT_FILE_PATH, true);
            BankToCustomerStatement bankToCustomerStatement = context.get(BankToCustomerStatement.class);
            context.set(Mt2SwiftDtoContextIdentifier.MT_TO_SWIFTDTO_OBJ, bankToCustomerStatement);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                bankToCustomerStatement.write(new File(outputFilePath));
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
