package com.brilliance.swift.mt2SwiftDto.camt053001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.vo.BankToCustomerStatement;
import com.brilliance.swift.vo.common.*;
import com.prowidesoftware.swift.model.field.Field65;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt9xx.MT940;

import java.util.List;

/**
 * @author zh
 * @create 2022-04-24 14:59
 */
public class Camt053001Parse65Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            BankToCustomerStatement bankToCustomerStatement = context.get(BankToCustomerStatement.class);
            AbstractMT abstractMT = context.get(AbstractMT.class);
            if (!"940".equals(abstractMT.getMessageType())) return;
            MT940 mt940 = (MT940) context.get(AbstractMT.class);
            List<Field65> field65List = mt940.getField65();
            if (field65List.size() > 0) {
                for (Field65 field65 : field65List) {
                    CashBalance cashBalance = new CashBalance();
                    cashBalance.setCode(BalanceTypeCode.FWAV);
                    cashBalance.setCdtDbtCode("D".equals(field65.getDCMark())? CdtDbtCode.DBIT:CdtDbtCode.CRDT);
                    cashBalance.setDate(DateUtil.parseDate("20"+field65.getDate(), "yyyyMMdd"));
                    CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                    ccyFormatAmount.setCcy(field65.getCurrency());
                    ccyFormatAmount.setAmt(field65.amount());
                    cashBalance.setAmt(ccyFormatAmount);
                    bankToCustomerStatement.addForwardAvailableBalance(cashBalance);
                }
            }
        }catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
