package com.brilliance.swift.mt2SwiftDto.pacs009001.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mt2SwiftDto.AbstractMt2SwiftDtoParseFields;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoFinancialInstitutionCreditTransfer;
import com.brilliance.swift.vo.common.PartyDto;
import com.prowidesoftware.swift.model.field.*;
import com.prowidesoftware.swift.model.mt.AbstractMT;
import com.prowidesoftware.swift.model.mt2xx.MT202;
import com.prowidesoftware.swift.model.mt2xx.MT202COV;

public class Pacs009001Parse53Field extends AbstractMt2SwiftDtoParseFields {
    @Override
    public void parseFields() throws SwiftException {
        try {
            VoFinancialInstitutionCreditTransfer financialInstitutionCreditTransfer = context.get(VoFinancialInstitutionCreditTransfer.class);
            PartyDto partyDto = null;
            if (getField53A() != null) {
                Field53A field53A = getField53A();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field53A.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field53A.getLine(1));
                }
                partyDto.setPartyBic(field53A.getBIC());
            } else if (getField53B() != null) {
                Field53B field53B = getField53B();
                if (StringUtil.isNotEmpty(field53B.getAccount())) {
                    financialInstitutionCreditTransfer.setSettleAccount(buildPartyAccount(field53B.getLine(1)));
                }
            } else if (getField53D() != null) {
                Field53D field53D = getField53D();
                partyDto = new PartyDto();
                if (StringUtil.isNotEmpty(field53D.getAccount())) {
                    partyDto = buildPartyAccount(partyDto, field53D.getLine(1));
                }
                partyDto.setPartyName(field53D.getNameAndAddressLine1());
                if (StringUtil.isNotEmpty(field53D.getNameAndAddressLine2())) {
                    partyDto.addAddress(field53D.getNameAndAddressLine2());
                }
                if (StringUtil.isNotEmpty(field53D.getNameAndAddressLine3())) {
                    partyDto.addAddress(field53D.getNameAndAddressLine3());
                }
                if (StringUtil.isNotEmpty(field53D.getNameAndAddressLine4())) {
                    partyDto.addAddress(field53D.getNameAndAddressLine4());
                }
            }
            if (partyDto != null) {
                financialInstitutionCreditTransfer.setInstgAgtParty(partyDto);
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    private Field53A getField53A() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField53A();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField53A();
        }
    }

    private Field53B getField53B() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField53B();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField53B();
        }
    }

    private Field53D getField53D() {
        if (isCov()) {
            MT202COV mt202Cov = (MT202COV)context.get(AbstractMT.class);
            return mt202Cov.getField53D();
        } else {
            MT202 mt202 = (MT202)context.get(AbstractMT.class);
            return mt202.getField53D();
        }
    }
}
