package com.brilliance.swift.mx2mt.mt103.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;

/**
 *对于所有代理行，如果xml报文中有代理行的bic，并且账户和清算代码都存在，则MT账号取账户；
 *  * 如果代理行没有bic，MT账号优先取清算代码，没有的话再取账户。
 */
public class Field57AGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "57A";

    private static String name_D = "57D";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String bicCode = mx_to_mtBICFI(bodyHdrParentElementName + ".CdtTrfTxInf.CdtrAgt");
        String account = mx_to_mtAccount(bodyHdrParentElementName + ".CdtTrfTxInf.CdtrAgtAcct");
        String mtClearSystemId = mx_to_mtClearingIdentifier(bodyHdrParentElementName + ".CdtTrfTxInf.CdtrAgt");
        String mtClearChannelId = mx_to_mtClearingIdentifierAndChannel(bodyHdrParentElementName + ".CdtTrfTxInf.CdtrAgt");
        String mtAccount = "";
        String value = "";
        if (StringUtil.isNotEmpty(bicCode)) {
            if (StringUtil.isNotEmpty(account)) {
                mtAccount = account;
            } else if (StringUtil.isNotEmpty(mtClearChannelId)){
                mtAccount = mtClearChannelId;
            } else {
                mtAccount = mtClearSystemId;
            }
            if (StringUtil.isNotEmpty(mtAccount)) {
                value = mtAccount + Mx2MtConstants.NEW_LINE + bicCode;
            } else {
                value = bicCode;
            }
            tags.add(new Tag(name_A, value));
        } else {
            String name = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.CdtrAgt.FinInstnId.Nm");
            String countryCode = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.CdtrAgt.FinInstnId.PstlAdr.Ctry");
            int addressLineCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.CdtrAgt.FinInstnId.PstlAdr.AdrLine");
            String mtNameAddress = "";
            if (addressLineCount > 0) {
                mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(bodyHdrParentElementName+ ".CdtTrfTxInf.CdtrAgt.FinInstnId");
            } else if (StringUtil.isNotEmpty(countryCode)) {
                mtNameAddress = mx_to_mtFinancialInstitutionNameAndStructuredAddress(bodyHdrParentElementName+ ".CdtTrfTxInf.CdtrAgt.FinInstnId", false);
            } else if (StringUtil.isNotEmpty(name)) {
                mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(bodyHdrParentElementName+ ".CdtTrfTxInf.CdtrAgt.FinInstnId");
            }
            if (StringUtil.isEmpty(mtNameAddress)) return;//如果name和地址不存在，返回。
            if (StringUtil.isNotEmpty(mtClearChannelId)) {
                mtAccount = mtClearChannelId;
            } else if (StringUtil.isNotEmpty(mtClearSystemId)) {
                mtAccount = mtClearSystemId;
            } else {
                mtAccount = account;
            }
            if (StringUtil.isNotEmpty(mtAccount)) {
                value = mtAccount + Mx2MtConstants.NEW_LINE + mtNameAddress;
            } else {
                value = mtNameAddress;
            }
            tags.add(new Tag(name_D, value));
        }
    }
}
