package com.brilliance.swift.mx2mt.mt103.impl;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 *70域取值规则：
 * MX_To_MTRemittanceInformation()
 * 参数1：CdtTrfTxInf.UltmtCdtr
 * 参数2：CdtTrfTxInf.UltmtDbtr
 * 参数3: CdtTrfTxInf.PmtId.EndToEndId
 * 参数4：CdtTrfTxInf.RltdRmtInf.RmtId
 * 参数5：CdtTrfTxInf.RmtInf
 * 参数6：CdtTrfTxInf.Purp
 * 1.如果参数4和参数5不存在
 *   ①如果参数1有值，/ULTB/MX_To_MTUltimateParty（CdtTrfTxInf.UltmtCdtr）,长度超过140就截图139位,最后一位给+
 *   ②如果参数2有值，/ULTD/MX_To_MTUltimateParty（CdtTrfTxInf.UltmtDbtr),长度超过140就截图139位,最后一位给+
 *   ③如果参数6有值，并且CdtTrfTxInf.Purp.Prty 不能mapping 【:26T:[A-Z0-9]{3}】,/PURP/CdtTrfTxInf.Purp.Cd
 *   ④如果参数3有值，并且CdtTrfTxInf.PmtId.EndToEndId不等于NOTPROVIDED并且CdtTrfTxInf.RmtInf.Ustrd不包含/ROC/，那么/ROC/CdtTrfTxInf.PmtId.EndToEndId
 * 2.如果参数4存在，/RELID/CdtTrfTxInf.RltdRmtInf.RmtId
 * 3.如果参数5存在，
 *   CdtTrfTxInf.RmtInf.Ustrd有值，/URI/CdtTrfTxInf.RmtInf.Ustrd
 *   CdtTrfTxInf.RmtInf.Strd有值，/SRI/CdtTrfTxInf.RmtInf.Strd
 */
public class Field70Generate extends AbstractMx2MtTagsGenerate {

    private static String name = "70";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String mt70FullString = "";
        String mtUltimateCreditor = mx_to_mtUltimateParty(bodyHdrParentElementName + ".CdtTrfTxInf.UltmtCdtr");
        if (StringUtil.isNotEmpty(mtUltimateCreditor)) {
            String str = "/ULTB/" + mtUltimateCreditor;
            if (str.length() > 140) str = str.substring(0, 139) + "+";
            if (StringUtil.isEmpty(mt70FullString)) {
                mt70FullString += str;
            } else {
                mt70FullString += "//" + str;
            }
        }
        String mtUltimateDebtor = mx_to_mtUltimateParty(bodyHdrParentElementName + ".CdtTrfTxInf.UltmtDbtr");
        if (StringUtil.isNotEmpty(mtUltimateDebtor)) {
            String str = "/ULTD/" + mtUltimateDebtor;
            if (str.length() > 140) str = str.substring(0, 139) + "+";
            if (StringUtil.isEmpty(mt70FullString)) {
                mt70FullString += str;
            } else {
                mt70FullString += "//" + str;
            }
        }
        String mxPurposeCode = getXmlNodeValue(bodyHdrParentElementName, document, ".CdtTrfTxInf.Purp.Cd");
        String mxPurposeProprietary = getXmlNodeValue(bodyHdrParentElementName, document, ".CdtTrfTxInf.Purp.Prtry");
        boolean mxPurposeFlag = true;
        if (StringUtil.isEmpty(mxPurposeCode)) {
            mxPurposeFlag = false;
        } else if (StringUtil.isNotEmpty(mxPurposeProprietary)) {
            String regex = ".*:26T:(.*).*";
            Pattern p = Pattern.compile(regex);
            Matcher m = p.matcher(mxPurposeProprietary);
            if (m.find()) {
                /**
                 * group(0)就是指的整个串，group(1)指的是第一个括号里的东西，group(2)指的第二个括号里的东西
                 */
                String code = m.group(1);
                if (code.matches("[A-Z0-9]{3}")) {
                    mxPurposeFlag = false;
                }
            }
        }
        if (mxPurposeFlag) {
            if (StringUtil.isEmpty(mt70FullString)) {
                mt70FullString += "/PURP/" + mxPurposeCode;
            } else {
                mt70FullString += "///PURP/" + mxPurposeCode;
            }
        }
        String endToEndIdentification = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.PmtId.EndToEndId");
        if (StringUtil.isNotEmpty(endToEndIdentification)) {
            if (StringUtil.isEmpty(mt70FullString)) {
                mt70FullString += "/ROC/" + endToEndIdentification;
            } else {
                mt70FullString += "///ROC/" + endToEndIdentification;
            }
        }
        String relatedRemittanceInformation = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.RltdRmtInf.RmtId");
        if (StringUtil.isNotEmpty(relatedRemittanceInformation)) {
            if (StringUtil.isEmpty(mt70FullString)) {
                mt70FullString += "/RELID/" + relatedRemittanceInformation;
            } else {
                mt70FullString += "///RELID/" + relatedRemittanceInformation;
            }
        }
        String remittanceInfoUnstructured = getXmlNodeValue(bodyHdrParentElementName, document, "CdtTrfTxInf.RmtInf.Ustrd");
        if (StringUtil.isNotEmpty(remittanceInfoUnstructured)) {
            if (StringUtil.isEmpty(mt70FullString)) {
                mt70FullString += "/URI/" + remittanceInfoUnstructured;
            } else {
                mt70FullString += "///URI/" + remittanceInfoUnstructured;
            }
        }
        int remittanceInfoStructuredCount = getXmlNodeCounts(bodyHdrParentElementName, document, "CdtTrfTxInf.RmtInf.Strd");
        if (remittanceInfoStructuredCount > 0) {
            if (StringUtil.isEmpty(mt70FullString)) {
                mt70FullString += "/SRI/+";
            } else {
                mt70FullString += "///SRI/+";
            }
        }
        if (StringUtil.isNotEmpty(mt70FullString)) {
            String value = StringUtil.getStringByEnter(mt70FullString, 35, 4);
            tags.add(new Tag(name, value));
        }
    }
}