package com.brilliance.swift.mx2mt.mt192292;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtCreator;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.mx2mt.Mx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.mt192292.impl.Field11SGenerate;
import com.brilliance.swift.mx2mt.mt192292.impl.Field20Generate;
import com.brilliance.swift.mx2mt.mt192292.impl.Field21Generate;
import com.brilliance.swift.mx2mt.mt192292.impl.Field79Generate;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.prowidesoftware.swift.model.SwiftBlock3;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.field.Field121;
import org.dom4j.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class Mx2Mtn92Creator extends AbstractMx2MtCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        context.set(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("AppHdr"));
        context.set(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("GrpHdr"));
        context.set(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, parentElementMaps.get("FIToFIPmtCxlReq"));
    }

    @Override
    public void withBlock3() throws SwiftException {
        super.withBlock3();
        SwiftBlock3 block3 = context.get(SwiftMessage.class).getBlock3();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyParentPath = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        String uetr = getXmlNodeValue(bodyParentPath, document, "FIToFIPmtCxlReq.Undrlyg.TxInf.OrgnlUETR");
        if (StringUtil.isNotEmpty(uetr)) {
            Field121 field121 = new Field121(uetr);
            block3.builder().setField121(field121);
        }
    }

    @Override
    public List<Mx2MtTagsGenerate> getGenerateTagList() {
        List<Mx2MtTagsGenerate> fieldsGenerateList = new ArrayList<>();
        fieldsGenerateList.add(new Field20Generate());
        fieldsGenerateList.add(new Field21Generate());
        fieldsGenerateList.add(new Field79Generate());
        fieldsGenerateList.add(new Field11SGenerate());
        return fieldsGenerateList;
    }

    @Override
    protected String getMtType() {
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyParentPath = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        String mtType = getXmlNodeValue(bodyParentPath, document, "FIToFIPmtCxlReq.Undrlyg.TxInf.OrgnlGrpInf.OrgnlMsgNmId");
        String msgType = "";
        if(StringUtil.isNotEmpty(mtType)){
            if(mtType.startsWith("pacs.008")){
                msgType = "103";
            }else if(mtType.startsWith("pacs.003")){
                msgType =  "104";
            }else if(mtType.startsWith("pacs.009")){
                msgType = "202";
            }else if(mtType.startsWith("pacs.010")){
                msgType = "204";
            }else if(mtType.matches("/MT10[0-9]{1}/")){
                msgType = mtType.substring(2);
            }else if(mtType.matches("/MT20[0-9]{1}/")){
                msgType = mtType.substring(2);
            }else {
                msgType = "202";
            }
        }
        if (msgType.startsWith("1")) {
            return Mx2MtConstants.MT_TYPE_192;
        } else if(msgType.startsWith("2")){
            return Mx2MtConstants.MT_TYPE_292;
        }else {
            return "类型错误";
        }
    }
}
