package com.brilliance.swift.mx2mt.mt202Retn;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtCreator;
import com.brilliance.swift.mx2mt.Mx2MtContextIdentifier;
import com.brilliance.swift.mx2mt.Mx2MtTagsGenerate;
import com.brilliance.swift.mx2mt.mt202Retn.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.common.ServiceLevelCode;
import com.prowidesoftware.swift.model.SwiftBlock3;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.field.Field111;
import com.prowidesoftware.swift.model.field.Field121;
import org.dom4j.Document;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class Mx2Mt202RetnCreator extends AbstractMx2MtCreator {

    @Override
    public void preProcess() {
        super.preProcess();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        Map<String, String> parentElementMaps = XmlUtil.getParentElementMaps(document);
        context.set(Mx2MtContextIdentifier.APPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("AppHdr"));
        context.set(Mx2MtContextIdentifier.GRPHDR_PARENT_ELEMENT_NAME, parentElementMaps.get("GrpHdr"));
        context.set(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, parentElementMaps.get("TxInf"));
    }

    @Override
    public void withBlock3() throws SwiftException {
        super.withBlock3();
        SwiftBlock3 block3 = context.get(SwiftMessage.class).getBlock3();
        Document document = (Document)context.get(Mx2MtContextIdentifier.MX_XMl_DOCUMENT, true);
        String bodyParentPath = (String)context.get(Mx2MtContextIdentifier.BODY_PARENT_ELEMENT_NAME, true);
        String serviceType = "";
        int serviceLevelCount = getXmlNodeCounts(bodyParentPath, document, "TxInf.OrgnlTxRef.PmtTpInf.SvcLvl");
        if (serviceLevelCount > 0) {
            for (int i=0; i<serviceLevelCount; i++) {
                String serviceLevelCode = getXmlNodeValue(bodyParentPath, document, "TxInf.OrgnlTxRef.PmtTpInf.SvcLvl("+i+").Cd");
                if (ServiceLevelCode.G001.value().equals(serviceLevelCode)
                        || ServiceLevelCode.G002.value().equals(serviceLevelCode)
                        || ServiceLevelCode.G003.value().equals(serviceLevelCode)
                        || ServiceLevelCode.G004.value().equals(serviceLevelCode)) {
                    serviceType = serviceLevelCode.substring(1);
                    break;
                }
            }
        }
        if (StringUtil.isNotEmpty(serviceType)) {
            Field111 field111 = new Field111(serviceType);
            block3.builder().setField111(field111);
        }
        String uetr = getXmlNodeValue(bodyParentPath, document, "TxInf.OrgnlUETR");
        if (StringUtil.isNotEmpty(uetr)) {
            Field121 field121 = new Field121(uetr);
            block3.builder().setField121(field121);
        }
    }

    @Override
    public List<Mx2MtTagsGenerate> getGenerateTagList() {
        List<Mx2MtTagsGenerate> fieldsGenerateList = new ArrayList<>();
        fieldsGenerateList.add(new Field20Generate());
        fieldsGenerateList.add(new Field21Generate());
        fieldsGenerateList.add(new Field13CGenerate());
        fieldsGenerateList.add(new Field32AGenerate());
        fieldsGenerateList.add(new Field52AGenerate());
        fieldsGenerateList.add(new Field53AGenerate());
        fieldsGenerateList.add(new Field56AGenerate());
        fieldsGenerateList.add(new Field57AGenerate());
        fieldsGenerateList.add(new Field58AGenerate());
        fieldsGenerateList.add(new Field72Generate());
        return fieldsGenerateList;
    }

    @Override
    protected String getMtType() {
        return Mx2MtConstants.MT_TYPE_202;
    }

}