package com.brilliance.swift.mx2mt.mt900910.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.StringUtil;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;
import com.prowidesoftware.swift.model.mx.dic.CreditDebitCode;

import java.util.List;

/**
 * 50A
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><Dbtr><Pty><Id><OrgId><AnyBIC>
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><DbtrAcct><Id><IBAN>
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><DbtrAcct><Id><Othr><Id>
 *
 * 50K
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><Dbtr><Pty><Nm>
 * <Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><Dbtr><Pty><PstlAdr><AdrLine>
 */
public class Field50aGenerate extends AbstractMx2MtTagsGenerate {

    private static String name_A = "50A";

    private static String name_F = "50F";

    private static String name_K = "50K";

    @Override
    public void tagGenerate() throws SwiftException {
        SwiftMessage swiftMessage = context.get(SwiftMessage.class);
        List<Tag> tags = swiftMessage.getBlock4().getTags();
        String cdtDbtInd = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.CdtDbtInd");
        if (!CreditDebitCode.CRDT.value().equals(cdtDbtInd)) {
            return;
        }
        String value = "";
        String partyPath = bodyHdrParentElementName + ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty";
        String bicCode = mx_to_mtAnyBIC(bodyHdrParentElementName + ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty");
        String countryCode = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.Ctry");
        String name = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.Nm");
        int addressLineCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Pty.PstlAdr.AdrLine");
        String account = mx_to_mtAccount(bodyHdrParentElementName + ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.DbtrAcct");
        if (StringUtil.isNotEmpty(bicCode)) {
            if (StringUtil.isNotEmpty(account)) {
                value = account + Mx2MtConstants.NEW_LINE + bicCode;
            } else {
                value = bicCode;
            }
            tags.add(new Tag(name_A, value));
        } else if (StringUtil.isNotEmpty(countryCode)) {
            String nameAddress = mx_to_mtFATFNameAndAddress(partyPath);
            if (StringUtil.isEmpty(account)) {
                account = mx_to_mtFATFIdentification(partyPath);
                if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                    account = account.substring(0, 35);
                }
            }
            if (StringUtil.isEmpty(account)) {
                account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
            }
            value = account + Mx2MtConstants.NEW_LINE + nameAddress;
            tags.add(new Tag(name_F, value));
        } else if (addressLineCount > 0) {
            boolean structuredAddressIndicator = mx_to_mtAddressLineType(partyPath);
            if (structuredAddressIndicator) {
                String nameAddress = mx_to_mtFATFNameAndAddress2(partyPath);
                if (StringUtil.isEmpty(account)) {
                    account = mx_to_mtFATFIdentification(partyPath);
                    if (StringUtil.isNotEmpty(account) && account.length() > 35) {
                        account = account.substring(0, 35);
                    }
                }
                if (StringUtil.isEmpty(account)) {
                    account = "/" + Mx2MtConstants.MX_TO_MT_DEFAULT_VALUE;
                }
                value = account + Mx2MtConstants.NEW_LINE + nameAddress;
                tags.add(new Tag(name_F, value));
            } else {
                String mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(partyPath);
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + mtNameAddress;
                } else {
                    value = mtNameAddress;
                }
                tags.add(new Tag(name_K, value));
            }
        } else if (StringUtil.isNotEmpty(name)) {
            String mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(partyPath);
            if (StringUtil.isNotEmpty(account)) {
                value = account + Mx2MtConstants.NEW_LINE + mtNameAddress;
            } else {
                value = mtNameAddress;
            }
            tags.add(new Tag(name_K, value));
        }
        if (StringUtil.isEmpty(value)) {
            bicCode = mx_to_mtBICFI(bodyHdrParentElementName + ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt");
            if (StringUtil.isNotEmpty(bicCode)) {
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + bicCode;
                } else {
                    value = bicCode;
                }
                tags.add(new Tag(name_A, value));
            } else {
                name = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.Nm");
                countryCode = getXmlNodeValue(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.Ctry");
                addressLineCount = getXmlNodeCounts(bodyHdrParentElementName, document, "Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId.PstlAdr.AdrLine");
                String mtNameAddress = "";
                if (addressLineCount > 0) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(bodyHdrParentElementName+ ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId");
                } else if (StringUtil.isNotEmpty(countryCode)) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndStructuredAddress(bodyHdrParentElementName+ ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId", false);
                } else if (StringUtil.isNotEmpty(name)) {
                    mtNameAddress = mx_to_mtFinancialInstitutionNameAndUnstructuredAddress(bodyHdrParentElementName+ ".Ntfctn.Ntry.NtryDtls.TxDtls.RltdPties.Dbtr.Agt.FinInstnId");
                }
                if (StringUtil.isEmpty(mtNameAddress)) return;//如果name和地址不存在，返回。
                if (StringUtil.isNotEmpty(account)) {
                    value = account + Mx2MtConstants.NEW_LINE + mtNameAddress;
                } else {
                    value = mtNameAddress;
                }
                tags.add(new Tag(name_K, value));
            }
        }
    }
}
