package com.brilliance.swift.mx2mt.mt942.impl;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.mx2mt.AbstractMx2MtTagsGenerate;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.NumberUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.CdtDbtCode;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.math.BigDecimal;
import java.util.List;

/**

 */
public class Field61Generate extends AbstractMx2MtTagsGenerate {

    private static String name = "61";

    @Override
    public void tagGenerate() throws SwiftException {
        try {
            SwiftMessage swiftMessage = context.get(SwiftMessage.class);
            List<Tag> tags = swiftMessage.getBlock4().getTags();
            int entryCount = getXmlNodeCounts(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry");
            if (entryCount > 0) {
                for (int i = 0; i < entryCount; i++) {
                    String value = "";
                    String valueDateStr = getXmlNodeValue(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry(" + i + ").ValDt.Dt");
                    if (StringUtil.isNotEmpty(valueDateStr)) {
                        XMLGregorianCalendar valueDate = DatatypeFactory.newInstance().newXMLGregorianCalendar(valueDateStr);
                        value += DateUtil.format(valueDate, "yyMMdd");
                    }
                    String bookDateStr = getXmlNodeValue(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry(" + i + ").BookgDt.Dt");
                    if (StringUtil.isNotEmpty(bookDateStr)) {
                        XMLGregorianCalendar bookDate = DatatypeFactory.newInstance().newXMLGregorianCalendar(bookDateStr);
                        value += DateUtil.format(bookDate, "MMdd");
                    }
                    String code = getXmlNodeValue(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry(" + i + ").Sts.Cd");
                    String reversalIndicator = getXmlNodeValue(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry(" + i + ").RvslInd");
                    String creditDebitIndicator = getXmlNodeValue(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry(" + i + ").CdtDbtInd");
                    if("BOOK".equals(code)){
                        if (StringUtil.isNotEmpty(reversalIndicator) && Boolean.valueOf(reversalIndicator)) {
                            if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                                value += "RC";
                            } else {
                                value += "RD";
                            }
                        } else {
                            if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                                value += "D";
                            } else {
                                value += "C";
                            }
                        }
                    }else if("FUTR".equals(code)||"PDNG".equals(code)||"INFO".equals(code)){
                        if (CdtDbtCode.DBIT.value().equals(creditDebitIndicator)) {
                            value += "ED";
                        } else {
                            value += "EC";
                        }
                    }
                    String amt = getXmlNodeValue(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry(" + i + ").Amt");
                    String ccy = getXmlNodeValue(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry(" + i + ").Amt@Ccy");
                    if (StringUtil.isNotEmpty(amt) && StringUtil.isNotEmpty(ccy)) {
                        value += NumberUtil.formatAmt(new BigDecimal(amt), ccy);
                    }
                    value += "NTRF";
                    String endToEndId = getXmlNodeValue(bodyHdrParentElementName, document, "BkToCstmrAcctRpt.Rpt.Ntry(" + i + ").NtryDtls.TxDtls.Refs.EndToEndId");
                    if (StringUtil.isNotEmpty(endToEndId)) {
                        if (endToEndId.length() > 16) {
                            endToEndId = endToEndId.substring(0, 15) + "+";
                        }
                        value += endToEndId;
                    } else {
                        value += Mx2MtConstants.MT_21_DEFAULT_VALUE;
                    }
                    tags.add(new Tag(name, value));
                }
            }
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
