package com.brilliance.swift.mx2swiftdto;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.common.*;
import org.apache.commons.io.FileUtils;
import org.dom4j.Document;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.io.IOException;
import java.math.BigDecimal;
import java.net.URL;
import java.text.ParseException;
import java.util.*;

public abstract class AbstractMx2SwiftDtoCreator implements Mx2SwiftDtoCreator{

    protected Mx2SwiftDtoContext context;

    public void setContext(Mx2SwiftDtoContext context) {
        this.context = context;
    }

    protected Document document = null;

    protected String appHdrParentElementName;

    protected String grpHdrParentElementName;

    protected String bodyHdrParentElementName;

    protected SwiftHeader swiftHeader;

    protected String defaultFormate = "yyyy-MM-dd HH:mm:ss,SSS";

    protected String defaultDateFormate = "yyyy-MM-dd";

    protected Map<String, Object> maps = new HashMap<>();

    @Override
    public void appHeader() throws SwiftException {
        try {
            swiftHeader = new SwiftHeader();
            String sendBicCode = getBicCode(appHdrParentElementName, document, "AppHdr.Fr.FIId.FinInstnId");
            swiftHeader.setSenderBic(sendBicCode);
            String receiverBicCode = getBicCode(appHdrParentElementName, document, "AppHdr.To.FIId.FinInstnId");
            swiftHeader.setReceiverBic(receiverBicCode);
            String createDateStr = getXmlNodeValue(appHdrParentElementName, document, "AppHdr.CreDt");
            if (StringUtil.isNotEmpty(createDateStr)) {
                XMLGregorianCalendar createDt = DatatypeFactory.newInstance().newXMLGregorianCalendar(createDateStr);
                Date createDate = DateUtil.formatAndParseDate(createDt.toGregorianCalendar().getTime(), defaultFormate);
                swiftHeader.setCreateDate(createDate);
            }
            String messageId = getXmlNodeValue(appHdrParentElementName, document, "AppHdr.BizMsgIdr");
            swiftHeader.setMessageId(messageId);
            String priority = getXmlNodeValue(appHdrParentElementName, document, "AppHdr.Prty");
            if (StringUtil.isNotEmpty(priority)) {
                swiftHeader.setMessagePriority(MessagePriority.fromValue(priority));
            }
            String messageDefId = getXmlNodeValue(appHdrParentElementName, document, "AppHdr.MsgDefIdr");
            swiftHeader.setMessageDefId(messageDefId);
            String businessService = getXmlNodeValue(appHdrParentElementName, document, "AppHdr.BizSvc");
            swiftHeader.setBusinessService(businessService);
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException("ERROR", e.getMessage());
        } catch (ParseException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    protected String getXmlNodeValue(String parentPath, Document document, String path) {
        if (StringUtil.isNotEmpty(parentPath)) {
            path = parentPath + "." + path;
        }
        return XmlUtil.getXmlNodeValue(document, path);
    }

    protected int getXmlNodeCounts(String parentPath, Document document, String path) {
        if (StringUtil.isNotEmpty(parentPath)) {
            path = parentPath + "." + path;
        }
        return XmlUtil.getChildrenCount(document, path, null);
    }

    protected String getBicCode(String type, Document document, String path) {
        //AnyBIC BICFI BICOrBEI BIC
        String bicCode = getXmlNodeValue(type, document, path+".AnyBIC");
        if (StringUtil.isEmpty(bicCode)) {
            bicCode = getXmlNodeValue(type, document, path+".BICFI");
        }
        if (StringUtil.isEmpty(bicCode)) {
            bicCode = getXmlNodeValue(type, document, path+".BICOrBEI");
        }
        if (StringUtil.isEmpty(bicCode)) {
            bicCode = getXmlNodeValue(type, document, path+".BIC");
        }
        return bicCode;
    }

    /**
     * FinancialInstitutionIdentification18
     * @param type
     * @param document
     * @param agtPath
     * @param agtAcctPath
     * @return
     */
    protected PartyDto agtConvertPartyDto(String type, Document document, String agtPath, String agtAcctPath) {
        String bicCode = getBicCode(type, document, agtPath+".FinInstnId");
        String name = getXmlNodeValue(type, document, agtPath+".FinInstnId.Nm");

        List<String> addressList = null;
        int addressCount = getXmlNodeCounts(type, document, agtPath+".FinInstnId.PstlAdr.AdrLine");
        if (addressCount > 0) {
            addressList = new ArrayList<>();
            for (int i=0; i<addressCount; i++) {
                String address = getXmlNodeValue(type, document, agtPath+".FinInstnId.PstlAdr.AdrLine("+i+")");
                addressList.add(address);
            }
        }
        String memberCode = getXmlNodeValue(type, document, agtPath+".FinInstnId.ClrSysMmbId.ClrSysId.Cd");
        String memberPrtry = getXmlNodeValue(type, document, agtPath+".FinInstnId.ClrSysMmbId.ClrSysId.Prtry");
        String memberId = getXmlNodeValue(type, document, agtPath+".FinInstnId.ClrSysMmbId.MmbId");
        ClearingSystemMember clrSysMember = null;
        if (StringUtil.isNotEmpty(memberCode)
                || StringUtil.isNotEmpty(memberPrtry)
                || StringUtil.isNotEmpty(memberId)) {
            clrSysMember = new ClearingSystemMember();
            clrSysMember.setCode(memberCode);
            clrSysMember.setProprietary(memberPrtry);
            clrSysMember.setId(memberId);
        }
        PartyAccount partyAccount = acctConvertPartyAcct(type, document, agtAcctPath);
        PartyDto partyDto = null;
        if (StringUtil.isNotEmpty(bicCode)
                || StringUtil.isNotEmpty(name)
                || clrSysMember != null
                || partyAccount != null) {
            partyDto = new PartyDto();
            partyDto.setPartyBic(bicCode);
            partyDto.setPartyName(name);
            if (addressList != null) {
                partyDto.getAddressList().addAll(addressList);
            }
            partyDto.setClrSysMmb(clrSysMember);
            partyDto.setPartyAcct(partyAccount);
        }
        return partyDto;
    }

    /**
     * PartyIdentification135
     * @param type
     * @param document
     * @param path
     * @param agtAcctPath
     * @return
     */
    protected PartyDto convertPartyDto(String type, Document document, String path, String agtAcctPath) {
        String bicCode = getBicCode(type, document, path+".Id.OrgId");
        String name = getXmlNodeValue(type, document, path+".Nm");

        List<String> addressList = null;
        int addressCount = getXmlNodeCounts(type, document, path+".PstlAdr.AdrLine");
        if (addressCount > 0) {
            addressList = new ArrayList<>();
            for (int i=0; i<addressCount; i++) {
                String address = getXmlNodeValue(type, document, path+".PstlAdr.AdrLine("+i+")");
                addressList.add(address);
            }
        }
        PartyAccount partyAccount = acctConvertPartyAcct(type, document, agtAcctPath);
        PartyDto partyDto = null;
        if (StringUtil.isNotEmpty(bicCode)
                || StringUtil.isNotEmpty(name)
                || partyAccount != null) {
            partyDto = new PartyDto();
            partyDto.setPartyBic(bicCode);
            partyDto.setPartyName(name);
            if (addressList != null) {
                partyDto.getAddressList().addAll(addressList);
            }
            partyDto.setPartyAcct(partyAccount);
        }
        return partyDto;
    }

    /**
     * CashAccount38
     * @param type
     * @param document
     * @param agtAcctPath
     * @return
     */
    protected PartyAccount acctConvertPartyAcct(String type, Document document, String agtAcctPath) {
        String account = getXmlNodeValue(type, document, agtAcctPath+".Id.Othr.Id");
        String ibanAcct = getXmlNodeValue(type, document, agtAcctPath+".Id.IBAN");
        String acctCcy = getXmlNodeValue(type, document, agtAcctPath+".Ccy");
        String acctName = getXmlNodeValue(type, document, agtAcctPath+".Nm");
        String acctTypeCode = getXmlNodeValue(type, document, agtAcctPath+".Tp.Cd");
        String acctTypeProprietary = getXmlNodeValue(type, document, agtAcctPath+".Tp.Prtry");
        String acctSchemeTypeCode = getXmlNodeValue(type, document, agtAcctPath+".Id.Othr.SchmeNm.Cd");
        String acctSchemeTypeProprietary = getXmlNodeValue(type, document, agtAcctPath+".Id.Othr.SchmeNm.Prtry");
        PartyAccount partyAccount = null;
        if (StringUtil.isNotEmpty(account) || StringUtil.isNotEmpty(ibanAcct)) {
            partyAccount = new PartyAccount();
            partyAccount.setAccount(account);
            partyAccount.setIbanAcct(ibanAcct);
            partyAccount.setAcctCcy(acctCcy);
            partyAccount.setAcctName(acctName);
            if (StringUtil.isNotEmpty(acctTypeCode) || StringUtil.isNotEmpty(acctTypeProprietary)) {
                AcctType acctType = new AcctType();
                acctType.setCode(AcctTypeCode.valueOf(acctTypeCode));
                acctType.setProprietary(acctTypeProprietary);
                partyAccount.setAcctType(acctType);
            }
            if (StringUtil.isNotEmpty(acctSchemeTypeCode) || StringUtil.isNotEmpty(acctSchemeTypeProprietary)) {
                AcctSchemeType acctSchemeType = new AcctSchemeType();
                acctSchemeType.setCode(AcctSehemeTypeCode.valueOf(acctSchemeTypeCode));
                acctSchemeType.setProprietary(acctSchemeTypeProprietary);
                partyAccount.setAcctSehemeType(acctSchemeType);
            }
        }
        return partyAccount;
    }

    /**
     * 根据下标转BalanceCash
     * @param parentPath
     * @param document
     * @param balancePath
     * @param index
     * @return
     */
    protected CashBalance convertCashBalanceByIndex(String parentPath, Document document, String balancePath, int index) {
        try {
            CashBalance cashBalance = null;
            int cashBalanceCount = getXmlNodeCounts(parentPath, document, balancePath);
            if (cashBalanceCount > index) {
                int i = index - 1;
                cashBalance = new CashBalance();
                String code = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Tp.CdOrPrtry.Cd");
                String proprietary = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Tp.CdOrPrtry.Prtry");
                String cdtDbtCode = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".CdtDbtInd");
                String dateStr = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Dt.Dt");
                if (StringUtil.isNotEmpty(dateStr)) {
                    Date date = DateUtil.parseDate(dateStr, defaultDateFormate);
                    cashBalance.setDate(date);
                }
                String ccy = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Amt@Ccy");
                String amtStr = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Amt");
                if (StringUtil.isNotEmpty(ccy) && StringUtil.isNotEmpty(amtStr)) {
                    CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                    ccyFormatAmount.setCcy(ccy);
                    ccyFormatAmount.setAmt(new BigDecimal(amtStr));
                    cashBalance.setAmt(ccyFormatAmount);
                }
                cashBalance.setCode(BalanceTypeCode.valueOf(code));
                cashBalance.setProprietary(proprietary);
                cashBalance.setCdtDbtCode(CdtDbtCode.valueOf(cdtDbtCode));

            }
            return cashBalance;
        } catch (ParseException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    /**
     * 根据类型转BalanceCash
     * @param parentPath
     * @param document
     * @param balancePath
     * @param balanceTypeCode
     * @return
     */
    protected List<CashBalance> convertCashBalanceByType(String parentPath, Document document, String balancePath, BalanceTypeCode balanceTypeCode) {
        try {
            List<CashBalance> cashBalances = new ArrayList<>();
            int cashBalanceCount = getXmlNodeCounts(parentPath, document, balancePath);
            if (cashBalanceCount > 0) {
                for (int i=0; i<cashBalanceCount; i++) {
                    String code = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Tp.CdOrPrtry.Cd");
                    if (balanceTypeCode.value().equals(code)) {
                        CashBalance cashBalance = new CashBalance();
                        String proprietary = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Tp.CdOrPrtry.Prtry");
                        String cdtDbtCode = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".CdtDbtInd");
                        String dateStr = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Dt.Dt");
                        Date date = DateUtil.parseDate(dateStr, defaultDateFormate);
                        String ccy = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Amt@Ccy");
                        String amtStr = getXmlNodeValue(parentPath, document, balancePath + "("+i+")" + ".Amt");
                        if (StringUtil.isNotEmpty(ccy) && StringUtil.isNotEmpty(amtStr)) {
                            CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
                            ccyFormatAmount.setCcy(ccy);
                            ccyFormatAmount.setAmt(new BigDecimal(amtStr));
                            cashBalance.setAmt(ccyFormatAmount);
                        }
                        cashBalance.setCode(BalanceTypeCode.valueOf(code));
                        cashBalance.setProprietary(proprietary);
                        cashBalance.setCdtDbtCode(CdtDbtCode.valueOf(cdtDbtCode));
                        cashBalance.setDate(date);
                        cashBalances.add(cashBalance);
                    }
                }
            }
            return cashBalances;
        } catch (ParseException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    public Object getXmlPathValue(Document document, String xmlPath) {
        try {
            xmlPath = xmlPath.replace("#APP", appHdrParentElementName).replace("#GRP", grpHdrParentElementName).replace("#BODY", bodyHdrParentElementName);
            Object value = null;
            if (xmlPath.indexOf("*") > -1) { //出现多个值
                String beginPath = xmlPath.substring(0, xmlPath.indexOf("*"));
                String endPath = xmlPath.substring(xmlPath.indexOf("*")+1);
                String type = "String";
                if (endPath.indexOf("&") > -1) {
                    type = endPath.substring(endPath.indexOf("&")+1);
                    endPath = endPath.substring(0, endPath.indexOf("&"));
                }
                int count = XmlUtil.getChildrenCount(document, beginPath, null);
                if (count > 0) {
                    if ("String".equalsIgnoreCase(type)) {
                        List<String> list = new ArrayList<>();
                        for (int i=0; i<count; i++) {
                            String xmlValue = XmlUtil.getXmlNodeValue(document, beginPath+"("+i+")."+endPath);
                            list.add(xmlValue);
                        }
                        value = list;
                    } else if ("BigDecimal".equalsIgnoreCase(type)) {
                        List<BigDecimal> list = new ArrayList<>();
                        for (int i=0; i<count; i++) {
                            String xmlValue = XmlUtil.getXmlNodeValue(document, beginPath+"("+i+")."+endPath);
                            list.add(new BigDecimal(xmlValue));
                        }
                        value = list;
                    }
                }
            } else if (xmlPath.indexOf("&") > -1) { //数据类型
                String type = xmlPath.substring(xmlPath.indexOf("&")+1);
                xmlPath = xmlPath.substring(0, xmlPath.indexOf("&"));
                String xmlValue = XmlUtil.getXmlNodeValue(document, xmlPath);
                if ("DATE".equalsIgnoreCase(type) && StringUtil.isNotEmpty(xmlValue)) {
                    XMLGregorianCalendar dtTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(xmlValue);
                    value = DateUtil.format(dtTm.toGregorianCalendar().getTime(), defaultFormate);
                } else if ("BigDecimal".equalsIgnoreCase(type) && StringUtil.isNotEmpty(xmlValue)) {
                    value = new BigDecimal(xmlValue);
                } else if ("List<String>".equalsIgnoreCase(type) && StringUtil.isNotEmpty(xmlValue)) {
                    int count = XmlUtil.getChildrenCount(document, xmlPath, null);
                    if (count > 0) {
                        List<String> list = new ArrayList<>();
                        for (int i=0; i<count; i++) {
                            xmlValue = XmlUtil.getXmlNodeValue(document, xmlPath+"("+i+")");
                            list.add(xmlValue);
                        }
                        value = list;
                    }
                }
            } else {
                value = XmlUtil.getXmlNodeValue(document, xmlPath);
            }
            return value;
        } catch (DatatypeConfigurationException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }

    /**
     * 传配置文件名称，
     * 根据配置文件将MX 模型转换成Swift Dto JSON map
     * @param fileName
     */
    protected void readPropertyFile(String fileName) {
        try {

            ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();
            URL resource = contextClassLoader.getResource("template/mx2swiftdto/"+fileName);
            if (resource == null) {
                resource = AbstractMx2SwiftDtoCreator.class.getClassLoader().getResource("template/mx2swiftdto/"+fileName);
            }
            File propertyFile = new File(resource.getPath());
            List<String> properties = FileUtils.readLines(propertyFile);
            if (properties.size() > 0) {
                for (String property : properties) {
                    if (property.startsWith("#")) {
                        continue;//过滤注释
                    }
                    String[] strArr = property.split("=");
                    if (strArr.length != 2) {
                        continue;//过滤掉不符合规则的配置
                    }
                    String key = strArr[0];
                    String xmlPath = strArr[1];
                    String[] xmlPaths = xmlPath.split("\\?");
                    Object xmlValue = null;
                    for (String path : xmlPaths) {
                        xmlValue = getXmlPathValue(document, path);//?表示优先级，如果取到值就跳出循环
                        if (xmlValue != null) break;
                    }
                    if (xmlValue == null) continue;
                    String[] keys = key.split("\\.");
                    if (keys.length == 1) {
                        maps.put(keys[0], xmlValue); //如果只有一个节点，直接put值
                    } else { //如果节点值超过1个，先赋值第一个节点，再循环赋值，最后一个节点直接put值。
                        Map<String, Object> keyMap = null;
                        if (maps.containsKey(keys[0])) {
                            keyMap = (Map<String, Object>)maps.get(keys[0]);
                        } else {
                            keyMap = new HashMap<>();
                            maps.put(keys[0], keyMap);
                        }
                        for (int i=1; i<keys.length; i++) {
                            if (i == keys.length-1) {
                                keyMap.put(keys[i], xmlValue);
                                break;
                            }
                            if (!keyMap.containsKey(keys[i])) {
                                keyMap.put(keys[i], new HashMap<>());
                            }
                            keyMap = (Map<String, Object>)keyMap.get(keys[i]);
                        }
                    }
                }
            }
        } catch (IOException e) {
            throw new SwiftException("ERROR", e.getMessage());
        }
    }
}
