package com.brilliance.swift.swiftdto2mt;

import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.common.*;

public abstract class AbstractSwiftDto2MtTagGenerate implements SwiftDto2MtTagGenerate{

    protected SwiftDto2MtContext context;

    public SwiftDto2MtContext getContext() {
        return context;
    }

    public AbstractSwiftDto2MtTagGenerate setContext(SwiftDto2MtContext context) {
        this.context = context;
        return this;
    }

    public ClearingSystemMemberCode getClsSysMemberByValue(String value) {
        ClearingSystemMemberCode code = null;
        ClearingSystemMemberCode[] values = ClearingSystemMemberCode.values();
        for (ClearingSystemMemberCode tmpCode : values) {
            if (tmpCode.value().equals(value)) {
                code = tmpCode;
                break;
            }
        }
        return code;
    }

    /**
     *
     * 2.如果IBAN有值，直接取 / + IBANACCOUNT
     * 如果CUID = ACCTSCHEMETYPE 并且account长度等于6，直接取 //CH + account
     * 否则直接取 / + account
     * @param partyDto
     * @return
     */
    protected String getAccount(PartyDto partyDto) {
        if (partyDto == null) {
            return null;
        }
        String account = "";
        ClearingSystemMember clrSysMmb = partyDto.getClrSysMmb();
        if (clrSysMmb != null) {
            ClearingSystemMemberCode memberCode = getClsSysMemberByValue(clrSysMmb.getCode());
            if (memberCode != null) {
                account = "//" + memberCode.desc();
            } else {
                account = "//" + clrSysMmb.getCode();
            }
            account += clrSysMmb.getId();
        } else {
            PartyAccount partyAcct = partyDto.getPartyAcct();
            if (partyAcct != null) {
                String ibanAcct = partyAcct.getIbanAcct();
                if (StringUtil.isNotEmpty(ibanAcct)) {
                    account = "/" + ibanAcct;
                } else {
                    String acct = partyAcct.getAccount();
                    if (StringUtil.isNotEmpty(acct)) {
                        AcctSchemeType acctSehemeType = partyAcct.getAcctSehemeType();
                        if (acctSehemeType != null
                            && AcctSehemeTypeCode.CUID.equals(acctSehemeType.getCode())
                            && acct.length() == 6) {
                            account = "//CH" + acct;
                        } else {
                            account = "/" + acct;
                        }
                    }
                }
            }
        }
        if (account.length() > 35) {
            account = account.substring(0, 35);
        }
        return account;
    }

}
