package com.brilliance.swift.swiftdto2mt;

import com.brilliance.swift.constants.Mx2MtConstants;
import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mt.mt103.SwiftDto2Mt103Creator;
import com.brilliance.swift.swiftdto2mt.mt202.SwiftDto2Mt202Creator;
import com.brilliance.swift.swiftdto2mt.mt900910.SwiftDto2Mt900910Creator;
import com.brilliance.swift.swiftdto2mt.mt940950.SwiftDto2Mt940950Creator;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.SwiftDto;

import java.util.Map;

public class SwiftDto2MtCreatorManager {

    public String swiftDto2Mt(SwiftDto swiftDto, String fileOutputPath, Map<String, Object> extraMap) throws SwiftException {
        SwiftDto2MtContext context = new SwiftDto2MtContext();
        context.set(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ, swiftDto);
        context.set(SwiftDto2MtContextIdentifier.MT_OUTPUT_FILE_PATH, fileOutputPath);
        String applicationMode = "O";//代表是收报，默认值
        if (extraMap != null) {
            applicationMode = (String) extraMap.get(Mx2MtConstants.APPLICATION_MODE);
            if (StringUtil.isEmpty(applicationMode)) {
                String bnkBic = (String)extraMap.get("bnkBic");//得到本行的bicCode
                if (StringUtil.isNotEmpty(bnkBic)) {
                    if (bnkBic.equals(swiftDto.getSwiftHeader().getSenderBic())) {
                        applicationMode = "I";//如果发报行和本行bic一样，表示是发报
                    }
                }
            }
        }
        context.putAll(extraMap);
        context.set(Mx2MtConstants.APPLICATION_MODE, applicationMode);
        AbstractSwiftDto2MtCreator creator = getCreator(swiftDto.getSwiftHeader().getMessageType());
        creator.setContext(context);
        creator.preProcess();
        creator.withBlock1();
        creator.withBlock2();
        creator.withBlock3();
        creator.withBlock4();
        creator.withBlock5();
        creator.postProcess();
        String xmlStr = (String)context.get(SwiftDto2MtContextIdentifier.MT_TXT);
        return xmlStr;
    }

    public AbstractSwiftDto2MtCreator getCreator(String messageType) {
        if ("pacs.008.001".equals(messageType)) {
            return new SwiftDto2Mt103Creator();
        } else if ("pacs.009.001".equals(messageType)) {
            return new SwiftDto2Mt202Creator();
        }else if("camt.054.001".equals(messageType)){
            return new SwiftDto2Mt900910Creator();
        } else if("camt.053.001".equals(messageType)){
            return new SwiftDto2Mt940950Creator();
        }
        else {
            throw new SwiftException("Invalid message type");
        }
    }
}
