package com.brilliance.swift.swiftdto2mt.mt103;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mt.AbstractSwiftDto2MtCreator;
import com.brilliance.swift.swiftdto2mt.SwiftDto2MtContextIdentifier;
import com.brilliance.swift.swiftdto2mt.SwiftDto2MtTagGenerate;
import com.brilliance.swift.swiftdto2mt.mt103.impl.*;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.VoCustomerCreditTransfer;
import com.brilliance.swift.vo.common.ServiceLevel;
import com.brilliance.swift.vo.common.ServiceLevelCode;
import com.brilliance.swift.vo.common.TransactionReference;
import com.prowidesoftware.swift.model.SwiftBlock3;
import com.prowidesoftware.swift.model.SwiftMessage;
import com.prowidesoftware.swift.model.Tag;

import java.util.ArrayList;
import java.util.List;

public class SwiftDto2Mt103Creator extends AbstractSwiftDto2MtCreator {

    @Override
    public void withBlock3() throws SwiftException {
        super.withBlock3();
        SwiftBlock3 block3 = context.get(SwiftMessage.class).getBlock3();
        VoCustomerCreditTransfer customerCreditTransfer = (VoCustomerCreditTransfer)context.get(SwiftDto2MtContextIdentifier.SWIFT_DTO_OBJ, true);
        ServiceLevel serviceLevel = customerCreditTransfer.getServiceLevel();
        if (serviceLevel != null) {
            if (ServiceLevelCode.G001.equals(serviceLevel.getCode())
                || ServiceLevelCode.G002.equals(serviceLevel.getCode())
                || ServiceLevelCode.G003.equals(serviceLevel.getCode())
                || ServiceLevelCode.G004.equals(serviceLevel.getCode())) {
                block3.getTags().add(new Tag("111", serviceLevel.getCode().value().substring(1)));
            }
        }
        TransactionReference txnRef = customerCreditTransfer.getTxnRef();
        if (txnRef != null && StringUtil.isNotEmpty(txnRef.getUetr())) {
            block3.getTags().add(new Tag("121", txnRef.getUetr()));
        }
    }

    @Override
    public List<SwiftDto2MtTagGenerate> getGenerateTagList() {
        List<SwiftDto2MtTagGenerate> list = new ArrayList<>();
        list.add(new Tag20Generate());
        list.add(new Tag13CGenerate());
        list.add(new Tag23BGenerate());
        list.add(new Tag23EGenerate());
        list.add(new Tag26TGenerate());
        list.add(new Tag32AGenerate());
        list.add(new Tag33BGenerate());
        list.add(new Tag36Generate());
        list.add(new Tag50Generate());
        list.add(new Tag51Generate());
        list.add(new Tag52Generate());
        list.add(new Tag53Generate());
        list.add(new Tag54Generate());
        list.add(new Tag55Generate());
        list.add(new Tag56Generate());
        list.add(new Tag57Generate());
        list.add(new Tag59Generate());
        list.add(new Tag70Generate());
        list.add(new Tag71Generate());
        list.add(new Tag72Generate());
        list.add(new Tag77BGenerate());
        return list;
    }

    @Override
    protected String getMtType() {
        return "103";
    }
}
