package com.brilliance.swift.swiftdto2mx.camt054001.v08;

import com.brilliance.swift.exception.SwiftException;
import com.brilliance.swift.swiftdto2mx.AbstractSwiftDto2MxCreator;
import com.brilliance.swift.swiftdto2mx.SwiftDto2MxContextIdentifier;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.vo.BankToCustomerDebitCreditNotification;
import com.brilliance.swift.vo.SwiftHeader;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.MessagePriority;
import com.brilliance.swift.vo.common.PartyDto;
import com.brilliance.swift.vo.common.TransactionReference;
import com.prowidesoftware.swift.model.mx.BusinessAppHdrV02;
import com.prowidesoftware.swift.model.mx.MxCamt05400108;
import com.prowidesoftware.swift.model.mx.dic.*;

import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.util.Date;

/**
 * @author zh
 * @create 2022-04-26 11:44
 */
public class SwiftDto2MxCamt054001Creator extends AbstractSwiftDto2MxCreator {
    @Override
    public void create() throws SwiftException {
        try {
            BankToCustomerDebitCreditNotification bankToCustomerDebitCreditNotification = (BankToCustomerDebitCreditNotification)context.get(SwiftDto2MxContextIdentifier.SWIFT_DTO_OBJ, true);
            if (bankToCustomerDebitCreditNotification == null) {
                return;
            }
            SwiftHeader swiftHeader = bankToCustomerDebitCreditNotification.getSwiftHeader();
            MxCamt05400108 mxCamt05400108 = new MxCamt05400108();
            //set AppHdr
            BusinessAppHdrV02 businessAppHdrV02 = new BusinessAppHdrV02();
            //fr
            Party44Choice fr = new Party44Choice();
            BranchAndFinancialInstitutionIdentification6 fiId = new BranchAndFinancialInstitutionIdentification6();
            FinancialInstitutionIdentification18 finInstnId = new FinancialInstitutionIdentification18();
            finInstnId.setBICFI(swiftHeader.getSenderBic());
            fiId.setFinInstnId(finInstnId);
            fr.setFIId(fiId);
            businessAppHdrV02.setFr(fr);
            //to
            Party44Choice to = new Party44Choice();
            BranchAndFinancialInstitutionIdentification6 toFiId = new BranchAndFinancialInstitutionIdentification6();
            FinancialInstitutionIdentification18 toFinInstnId = new FinancialInstitutionIdentification18();
            toFinInstnId.setBICFI(swiftHeader.getReceiverBic());
            toFiId.setFinInstnId(toFinInstnId);
            to.setFIId(toFiId);
            businessAppHdrV02.setTo(to);
            //
            XMLGregorianCalendar creDt = DateUtil.parseXMLGregorianCalendar(swiftHeader.getCreateDate());
            businessAppHdrV02.setCreDt(creDt);

            if (MessagePriority.NORM.equals(swiftHeader.getMessagePriority())) {
                businessAppHdrV02.setPrty(Priority2Code.NORM.value());
            } else if (MessagePriority.HIGH.equals(swiftHeader.getMessagePriority())) {
                businessAppHdrV02.setPrty(Priority2Code.HIGH.value());
            }
            businessAppHdrV02.setMsgDefIdr(swiftHeader.getMessageDefId());
            businessAppHdrV02.setBizMsgIdr(swiftHeader.getMessageId());
            businessAppHdrV02.setBizSvc(swiftHeader.getBusinessService());
            mxCamt05400108.setAppHdr(businessAppHdrV02);
            //grpHdr
            BankToCustomerDebitCreditNotificationV08 bkToCstmrDbtCdtNtfctn = new BankToCustomerDebitCreditNotificationV08();
            mxCamt05400108.setBkToCstmrDbtCdtNtfctn(bkToCstmrDbtCdtNtfctn);
            GroupHeader81 grpHdr = new GroupHeader81();
            grpHdr.setMsgId(swiftHeader.getMessageId());
            grpHdr.setCreDtTm(DateUtil.parseXMLGregorianCalendar(swiftHeader.getCreateDate()));
            grpHdr.setAddtlInf("");
            bkToCstmrDbtCdtNtfctn.setGrpHdr(grpHdr);
            //ntfcn
            AccountNotification17 ntfctn = new AccountNotification17();
            bkToCstmrDbtCdtNtfctn.addNtfctn(ntfctn);
            TransactionReference txnRef = bankToCustomerDebitCreditNotification.getTxnRef();
            String endToEndId = txnRef.getEndToEndId();//21
            String account = bankToCustomerDebitCreditNotification.getAccount().getAccount();//25
            String ibanAcct = bankToCustomerDebitCreditNotification.getAccount().getIbanAcct();//25
            Date valueDate = bankToCustomerDebitCreditNotification.getValueDate();//25a
            CcyFormatAmount valueAmount = bankToCustomerDebitCreditNotification.getValueAmount();//25a
            PartyDto debitParty = bankToCustomerDebitCreditNotification.getDebitParty();//50
            PartyDto debitAgtParty = bankToCustomerDebitCreditNotification.getDebitAgtParty();//52
            String cdtDbtCode = bankToCustomerDebitCreditNotification.getCdtDbtCode();
            PartyDto intrmyAgtParty = bankToCustomerDebitCreditNotification.getIntrmyAgtParty();//56
            String addtlTxInf = bankToCustomerDebitCreditNotification.getAddtlTxInf();//72
            //EndToEndId
            ReportEntry10 ntry = new ReportEntry10();
            ntfctn.addNtry(ntry);
            if(CreditDebitCode.CRDT.value().equals(cdtDbtCode)){
                ntry.setCdtDbtInd(CreditDebitCode.CRDT);
            }else if(CreditDebitCode.DBIT.value().equals(cdtDbtCode)){
                ntry.setCdtDbtInd(CreditDebitCode.DBIT);
            }
            EntryDetails9 ntryDtls =new EntryDetails9();
            ntry.addNtryDtls(ntryDtls);
            EntryTransaction10 txDtls = new EntryTransaction10();
            ntryDtls.addTxDtls(txDtls);
            TransactionParties6 rltdPties =new TransactionParties6();
            txDtls.setRltdPties(rltdPties);
            Party40Choice dbtr = new Party40Choice();
            rltdPties.setDbtr(dbtr);
            TransactionReferences6 refs =new TransactionReferences6();
            refs.setEndToEndId(endToEndId);
            refs.setUETR(txnRef.getUetr());
            txDtls.setRefs(refs);
            //IBAN Othr/Id
            if(account!=null||ibanAcct!=null){
                CashAccount39 acct = new CashAccount39();
                ntfctn.setAcct(acct);
                AccountIdentification4Choice id = new AccountIdentification4Choice();
                if(ibanAcct!=null){
                    id.setIBAN(account);
                }else {
                    GenericAccountIdentification1 othr = new GenericAccountIdentification1();
                    othr.setId(account);
                    id.setOthr(othr);
                }
                acct.setId(id);
            }
            //Dt Amt Ccy="XXX"
            if(valueDate!=null && valueAmount!=null){
                DateAndDateTime2Choice valDt = new DateAndDateTime2Choice();
                ntry.setValDt(valDt);
                XMLGregorianCalendar dt = DateUtil.parseXMLGregorianCalendar(valueDate);
                valDt.setDt(dt);
                ActiveOrHistoricCurrencyAndAmount amt = new ActiveOrHistoricCurrencyAndAmount();
                amt.setCcy(valueAmount.getCcy());
                amt.setValue(valueAmount.getAmt());
                ntry.setAmt(amt);
            }
            //<Ntfctn><Ntry><NtryDtls><TxDtls><RltdPties><Dbtr><Nm>
            if("CRDT".equals(cdtDbtCode)){
                if(debitParty!=null){
                    PartyIdentification135 pty = partyDtoConvertTr(debitParty);
                    dbtr.setPty(pty);
                    CashAccount38 dbtrAcct = partyDtoConvertAgtAccount(debitParty.getPartyAcct());
                    rltdPties.setDbtrAcct(dbtrAcct);
                }
                //<Ntfctn><Ntry><NtryDtls><TxDtls><RltdAgts><DbtrAcct><FinInstnId><BICFI>
                //<Ntfctn><Ntry><NtryDtls><TxDtls><RltdAgts><DbtrAcct><FinInstnId><ClrSysMmbId><ClrSysId><Cd>
                //<Ntfctn><Ntry><NtryDtls><TxDtls><RltdAgts><DbtrAcct><FinInstnId><ClrSysMmbId><ClrSysId><Prtry>
                //<Ntfctn><Ntry><NtryDtls><TxDtls><RltdAgts><DbtrAcct><FinInstnId><ClrSysMmbId><MmbId>
                if(debitAgtParty!=null){
                    TransactionAgents5 rltdAgts = new TransactionAgents5();
                    txDtls.setRltdAgts(rltdAgts);
                    BranchAndFinancialInstitutionIdentification6 dbtrAgt = partyDtoConvertAgt(debitAgtParty);
                    rltdAgts.setDbtrAgt(dbtrAgt);
                }
                //<Ntfctn><Ntry><NtryDtls><TxDtls><RltdAgts><IntrmyAgt1><FinInstnId><BICFI>
                if(intrmyAgtParty!=null){
                    TransactionAgents5 rltdAgts = new TransactionAgents5();
                    txDtls.setRltdAgts(rltdAgts);
                    BranchAndFinancialInstitutionIdentification6 intrmyAgt1 = partyDtoConvertAgt(intrmyAgtParty);
                    rltdAgts.setIntrmyAgt1(intrmyAgt1);
                }
            }else if("DBIT".equals(cdtDbtCode)){
                if(debitAgtParty!=null){
                    PartyIdentification135 pty = partyDtoConvertTr(debitAgtParty);
                    dbtr.setPty(pty);
                    CashAccount38 dbtrAcct = partyDtoConvertAgtAccount(debitAgtParty.getPartyAcct());
                    rltdPties.setDbtrAcct(dbtrAcct);
                }
            }
            if(addtlTxInf!=null){
                txDtls.setAddtlTxInf(addtlTxInf);
            }
            String xmlStr = mxCamt05400108.message();
            context.set(SwiftDto2MxContextIdentifier.MX_XML, xmlStr);
            String outputFilePath = (String)context.get(SwiftDto2MxContextIdentifier.MX_OUTPUT_FILE_PATH, true);
            if (StringUtil.isNotEmpty(outputFilePath)) {
                mxCamt05400108.write(new File(outputFilePath));
            }
        } catch (Exception e) {
            throw new SwiftException("ERROR", e.getMessage());
        }

    }
}
