package com.brilliance.swift.util;

import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import com.brilliance.swift.vo.MxMtReasonCodeInfo;
import com.brilliance.swift.vo.SwiftTransferErrorInfo;
import com.brilliance.swift.vo.common.ClearingSystemMemberCode;
import com.brilliance.swift.vo.common.OrganisationIdentificationCode;
import com.brilliance.swift.vo.common.PersonIdentificationCode;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.InputStream;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;

public class SwiftTransferUtil {

    public static XMLGregorianCalendar getXMLGregorianCalendarNow() {
        GregorianCalendar gregorianCalendar = new GregorianCalendar();
        DatatypeFactory datatypeFactory = null;
        try {
            datatypeFactory = DatatypeFactory.newInstance();
        } catch (DatatypeConfigurationException e) {
            e.printStackTrace();
        }
        XMLGregorianCalendar now = datatypeFactory.newXMLGregorianCalendar(gregorianCalendar);
        return now;
    }

    /**
     * Validate the field format notation types of character: A type of
     * character. Its explanation is:
     * <em>a = alphabetic letters (A through Z), upper case only: A-Z</em>
     * @param s
     *        - String, a string to be tested
     * @return boolean, true indicating it belongs to
     */
    public static boolean belongstoA(String s) {
        String[] a =
                new String[] {
                        "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T",
                        "U", "V", "W", "X", "Y", "Z" };
        return eachCharIn(s, a);
    }
    /**
     * Test if matching the A type of character (A-Z) at least min times and at
     * most max times. *
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param s
     *        - String, the string to be tested
     * @param min
     *        - int, at least min times
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToA(String s, int min, int max) {
        String restrictOccur = buildRegexQuantifier(min, max);
        return (!StringUtil.isEmpty(s) && s.matches("[A-Z]" + restrictOccur));
    }
    /**
     * Validate the field format notation types of character: C type of
     * character. Its explanation is:
     * <em>c = alphabetic letters (upper case) and digits only: A-Z0-9</em>
     * @param s
     *        - String, a string to be tested
     * @return boolean, true indicating it belongs to
     */
    public static boolean belongstoC(String s) {
        String[] a =
                new String[] {
                        "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F", "G", "H", "I", "J",
                        "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z" };
        return eachCharIn(s, a);
    }
    /**
     * Test if matching the C type of character (A-Z0-9) at least one time and
     * at most max times. *
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param s
     *        - String, the string to be tested
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToC(String s, int max) {
        return belongsToC(s, 1, max);
    }
    /**
     * Test if matching the C type of character (A-Z0-9) at least min times and
     * at most max times.
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param s
     *        - String, the string to be tested
     * @param min
     *        - int, at least min times
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToC(String s, int min, int max) {
        String restrictOccur = buildRegexQuantifier(min, max);
        return (!StringUtil.isEmpty(s) && s.matches("[A-Z0-9]" + restrictOccur));
    }
    /**
     * Validate the field format notation types of character: D type of
     * character. Its explanation is:
     * <em>d = digits with a decimal comma: 0-9,</em>
     * @param s
     *        - String, a string to be tested
     * @return boolean, true indicating it belongs to
     */
    public static boolean belongstoD(String s) {
        String[] a = new String[] { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "," };
        return eachCharIn(s, a);
    }
    /**
     * Test if matching the D type of character (0-9,) at least one time and at
     * most max times.
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param s
     *        - String, the string to be tested
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToD(String s, int max) {
        return belongsToD(s, 1, max);
    }
    /**
     * Test if matching the D type of character (0-9,) at least min times and at
     * most max times.
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param s
     *        - String, the string to be tested
     * @param min
     *        - int, at least min times
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToD(String s, int min, int max) {
        String restrictOccur = buildRegexQuantifier(min, max);
        return (!StringUtil.isEmpty(s) && !s.matches("[\\d+,\\d*]" + restrictOccur));
    }
    /**
     * Validate the field format notation types of character: N type of
     * character. Its explanation is:
     * <em>n = numeric digits (0 through 9) only: 0-9</em>
     * @param s
     *        - String, a string to be tested
     * @return boolean, true indicating it belongs to
     */
    public static boolean belongstoN(String s) {
        String[] a = new String[] { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9" };
        return eachCharIn(s, a);
    }
    /**
     * Test if matching the N type of character (0-9) at least one time and at
     * most max times.
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param
     *        - String, the string to be tested
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToN(String tag, int max) {
        return belongsToN(tag, 1, max);
    }
    /**
     * Test if matching the N type of character (0-9) at least min times and at
     * most max times.
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param s
     *        - String, the string to be tested
     * @param min
     *        - int, at least min times
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToN(String s, int min, int max) {
        String restrictOccur = buildRegexQuantifier(min, max);
        return (!StringUtil.isEmpty(s) && s.matches("[0-9]" + restrictOccur));
    }
    /**
     * Test if matching the X type of character (A-Z a-z 0-9 / - ? : ( ) . , ' +
     * SPACE CrLf) at least one time and at most max times.
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param s
     *        - String, the string to be tested
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToX(String s, int max) {
        return belongsToX(s, 1, max);
    }
    /**
     * Test if matching the x type of character (A-Z a-z 0-9 / - ? : ( ) . , ' +
     * SPACE CrLf) at least min times and at most max times.
     *
     * <pre>
     * 4!a ==> belongsToA(s, 0, 4)
     * 3!c ==> belongsToC(s, 0, 3)
     * 16x ==> belongsToX(s, 16) or belongsToX(s, 1, 16)
     * 15d ==> belongsToD(s, 15) or belongsToD(s, 1, 15)
     * 15n ==> belongsToN(s, 15) or belongsToN(s, 1, 15)
     * </pre>
     * @param s
     *        - String, the string to be tested
     * @param min
     *        - int, at least min times
     * @param max
     *        - int, at most max times
     * @return boolean, true indicating it matches
     */
    public static boolean belongsToX(String s, int min, int max) {
        String restrictOccur = buildRegexQuantifier(min, max);
        //sample: 35x
        String regexp = "^" + "[[A-Za-z0-9](/|\\-|\\?|:|(|)|\'|,|.|\\+|\" \")]" + restrictOccur + "$";
        return (!StringUtil.isEmpty(s) && s.matches(regexp));
    }
    /**
     * To build regular expression quantifier. The rule as follow:
     *
     * <pre>
     * [0,0] or [2,0] or [2,-1] ==> +
     * [0,3] ==> {3}
     * [1,3] ==> {1,3}
     * </pre>
     * @param min
     *        - int, at least min times
     * @param max
     *        - int, at most max times
     * @return String
     */
    private static String buildRegexQuantifier(int min, int max) {
        String restrictOccur = "";
        if (max <= 0) {
            restrictOccur = "+";
        } else if (min == 0) {
            restrictOccur = "{" + max + "}";
        } else {
            restrictOccur = "{" + min + "," + max + "}";
        }
        return restrictOccur;
    }
    /**
     * To check if each character in parameter <code>s</code> belongs to
     * specified character collection.
     * @param s
     *        - String, a string
     * @param legalCharacters
     *        - String[], specified character collection
     * @return boolean, true indicating they belongs to
     */
    private static boolean eachCharIn(String s, final String[] legalCharacters) {
        if (StringUtil.isEmpty(s)) {
            return false;
        }
        boolean flag = false;
        for (int i = 0; i < s.length(); ++i) {
            flag = false;
            String tmp = s.substring(i, i + 1);
            int len = legalCharacters.length;
            for (int j = 0; j < len; ++j) {
                if (tmp.equals(legalCharacters[j])) {
                    flag = true;
                    break;
                }
            }
            if (!flag) {
                break;
            }
        }
        return flag;
    }
    /**
     * To check if bic is correct SWIFT BIC (SWIFT code or BIC) with format
     * "4!a2!a2!c[3!c]".
     * @param bic
     *        - String, the string to be tested
     * @return boolean, true indicating it is correct BIC
     */
    public static boolean isBIC(String bic) {
        if (StringUtil.isEmpty(bic)) {
            return false;
        }
        boolean flag = true;
        if (bic.length() != 8 && bic.length() != 11) {
            flag = false;
        } else {
            String e = bic.substring(0, 4);//bank code
            String s2 = bic.substring(4, 6);//country code
            String s3 = bic.substring(6, 8);//location code
            flag = belongsToA(e, 0, 4) && belongsToA(s2, 0, 2) && belongsToC(s3, 0, 2);
            if (flag) {
                String s4 = "";
                if (bic.length() != 8) {
                    s4 = bic.substring(8);//branch code
                    flag = belongsToC(s4, 0, 3);
                }
            }
        }
        return flag;
    }

    /**
     * To check if the date is pattern "YYMMDD"
     * @param dateString
     *        - String, date string
     * @return boolean, true indicating the date has correct format
     */
    public static boolean isDateYYMMDD(String dateString) {
        boolean flag = true;
        dateString = dateString.trim();
        try {
            if (dateString.length() != 6) {
                return false;
            }
            String e = dateString.substring(0, 2);
            String smm = dateString.substring(2, 4);
            String sdd = dateString.substring(4);
            int yy = Integer.parseInt(e);
            int mm = Integer.parseInt(smm);
            int dd = Integer.parseInt(sdd);
            if (yy < 80 && yy > 60) {
                flag = false;
            }
            SimpleDateFormat sdf = new SimpleDateFormat("dd.MM.yyyy");
            String yyyy = "";
            if (yy >= 0 && yy <= 60) {
                yyyy = "20" + e;
            } else {
                yyyy = "19" + e;
            }
            Date tmpdate = sdf.parse(dd + "." + mm + "." + yyyy);
            String s = sdf.format(tmpdate);
            int tdd = Integer.parseInt(s.substring(0, 2));
            int tmm = Integer.parseInt(s.substring(3, 5));
            int tyy = Integer.parseInt(s.substring(8));
            if (yy != tyy || mm != tmm || dd != tdd) {
                flag = false;
            }
        } catch (Exception var15) {
            flag = false;
        }
        return flag;
    }
    /**
     * To check if the date is pattern "YYYYMMDD"
     * @param
     *        - String, date string
     * @return boolean, true indicating the date has correct format
     */
    public static boolean isDateYYYYMMDD(String dateString) {
        boolean result = true;
        if (belongsToN(dateString, 8, 8)) {
            try {
                SimpleDateFormat e = new SimpleDateFormat("yyyyMMdd");
                e.setLenient(false);
                e.parse(dateString);
            } catch (Exception e) {
                result = false;
            }
        } else {
            result = false;
        }
        return result;
    }
    /**
     * To test if the amount is valid
     * @param amount
     *        - String, amount text
     * @param fractionalDigits
     *        - Integer
     * @return boolean, true indicating amount is valid
     */
    public static boolean isAmountValid(String amount, Integer fractionalDigits) {
        if (!amount.matches("^\\d*.*$") || !amount.matches("^[^,]*.\\d{0," + fractionalDigits + "}$")) {
            return false;
        }
        return true;
    }
    /**
     * whether number string is null or zero
     * @param fieldValue
     *        - the number string
     * @return true if null or zero
     */
    public static boolean isNumNull(String fieldValue) {
        Integer fAmount = null;
        if (StringUtil.isEmpty(fieldValue))
            return true;
        else {
            try {
                fAmount = new Integer(fieldValue.trim());
                if (fAmount.intValue() == 0)
                    return true;
            } catch (Exception ex) {
                return true;
            }
        }
        return false;
    }
    /**
     * whether amount is null or 0.0
     * @param fieldValue
     *        - the amount
     * @return true if null or 0.0
     */
    public static boolean isAmountNull(String fieldValue) {
        BigDecimal fAmount = BigDecimal.ZERO;
        if (StringUtil.isEmpty(fieldValue))
            return true;
        else {
            try {
                fAmount = new BigDecimal(fieldValue.trim());
                if (fAmount.compareTo(new BigDecimal(0.0)) == 0) {
                    return true;
                }
            } catch (Exception ex) {
                return true;
            }
        }
        return false;
    }
    /**
     * To check the length of field value
     * @param value
     *        - String, value of field
     * @param minLength
     *        - int, required minimum length
     * @param maxLength
     *        - int, required maximum length
     * @return boolean, true indicating it is valid
     */
    public static boolean checkLength(String value, int minLength, int maxLength) {
        boolean result = true;
        if (StringUtil.isEmpty(value) || value.length() < minLength || value.length() > maxLength) {
            result = false;
        }
        return result;
    }
    /**
     * To check the number of line
     * @param rowNum
     *        - int, number of actual lines
     * @param min
     *        - int, the required minimum number of lines
     * @param max
     *        - int, the required maximum number of lines
     * @return boolean, true indicating the number of line is valid
     */
    public static boolean checkRowCount(int rowNum, int min, int max) {
        boolean result = true;
        if ((min > 0 && rowNum < min) || (rowNum > max)) {
            result = false;
        }
        return result;
    }

    /**
     *  [A-Z]{2,2}[0-9]{2,2}[a-zA-Z0-9]{1,30}
     */
    public static boolean checkIbanAccount(String account) {
        if (StringUtil.isEmpty(account) || account.length() < 5) {
            return false;
        }
        boolean result = false;
        String countyCode = account.substring(0, 2);
        String verifierCode = account.substring(2, 4);
        String realAcct = account.substring(4);
        if (countyCode.matches("[A-Z]{2,2}")
                && verifierCode.matches("[0-9]{2,2}")
                && realAcct.matches("[a-zA-Z0-9]{1,30}")) {
            result = true;
        }
        return result;
    }

    /**
     * 检查countrycode是否再EUCOUNTRY列表里面
     * 存在就返回true；否则返回false
     * @param countryCode
     * @return
     */
    public static boolean checkInEuCountryList(String countryCode) {
        String[] countrys = new String[]{"AD", "AT", "BE", "BG", "BV", "CH", "CY", "CZ", "DE", "DK", "ES",
                "EE", "FI", "FR", "GB", "GF", "GI", "GP", "GR", "HU", "IE", "IS", "IT", "LI", "LT", "LU",
                "LV", "MC", "MQ", "MT", "NL", "NO", "PL", "PM", "PT", "RE", "RO", "SE", "SI", "SJ", "SK", "SM", "TF", "VA"};
        for (String country : countrys) {
            if (countryCode.equalsIgnoreCase(country)) return true;
        }
        return false;
    }

    /**
     * 根据字符串取到清算系统代码
     * ClearingSystemMemberCode对象包含了
     * MXClearingSystemMemberCode和MTClearingSystemMemberCode mapping对应关系
     * @param value
     * @return
     */
    public static ClearingSystemMemberCode getClsSysMemberByValue(String value) {
        ClearingSystemMemberCode code = null;
        ClearingSystemMemberCode[] values = ClearingSystemMemberCode.values();
        for (ClearingSystemMemberCode tmpCode : values) {
            if (tmpCode.value().equals(value)) {
                code = tmpCode;
                break;
            }
        }
        return code;
    }

    /**
     * 根据mxcode取OrganisationIdentificationCode
     */
    public static OrganisationIdentificationCode getOrganisationIdentificationCodeByCode(String mxCode) {
        OrganisationIdentificationCode code = null;
        OrganisationIdentificationCode[] values = OrganisationIdentificationCode.values();
        for (OrganisationIdentificationCode tmpCode : values) {
            if (tmpCode.value().equals(mxCode)) {
                code = tmpCode;
                break;
            }
        }
        return code;
    }

    /**
     * 根据mxcode取PersonIdentificationCode
     */
    public static PersonIdentificationCode getPersonIdentificationCodeByCode(String mxCode) {
        PersonIdentificationCode code = null;
        PersonIdentificationCode[] values = PersonIdentificationCode.values();
        for (PersonIdentificationCode tmpCode : values) {
            if (tmpCode.value().equals(mxCode)) {
                code = tmpCode;
                break;
            }
        }
        return code;
    }

    /**
     * 根据ErrorCodesRETNREJT.xlsx文件返回
     * List<MxMtReasonCodeInfo>
     */
    public static List<MxMtReasonCodeInfo> getMxMtReasonCodes() {
        List<MxMtReasonCodeInfo> list = new ArrayList<>();
        InputStream resourceAsStream = SwiftTransferUtil.class.getResourceAsStream("/ErrorCodesRETNREJT.xlsx");
        ExcelReader reader = ExcelUtil.getReader(resourceAsStream);
        List<Map<String, Object>> content = reader.readAll();
        if (content.size() > 0) {
            for (int i=0; i<content.size(); i++) {
                Map<String, Object> contentMaps = content.get(i);
                String isoCode = (String)contentMaps.get("ISOCode");
                String mtCode = (String)contentMaps.get("MTCode");
                if (StringUtil.isNotEmpty(isoCode) && StringUtil.isNotEmpty(mtCode)) {
                    MxMtReasonCodeInfo info = new MxMtReasonCodeInfo();
                    info.setMtCode(mtCode);
                    String mtDescription = (String)contentMaps.get("MTDescription");
                    info.setMtDescription(mtDescription);
                    Object obj = contentMaps.get("IsMXErrorCodePresent");
                    if (obj != null && (Boolean)obj) {
                        info.setMxErrorCodePresent(true);
                    }
                    obj = contentMaps.get("IsMTErrorCodePresent");
                    if (obj != null && (Boolean)obj) {
                        info.setMtErrorCodePresent(true);
                    }
                    info.setIsoCode(isoCode);
                    String isoRjtRntCode = (String)contentMaps.get("ISORejectAndReturnCodes");
                    info.setIsoRjtRntCode(isoRjtRntCode);
                    String isoRjtRntCodeDefinition = (String)contentMaps.get("ISORejectAndReturnCodesDefinition");
                    info.setIsoRjtRntCodeDefinition(isoRjtRntCodeDefinition);
                    list.add(info);
                }
            }
        }
        return list;
    }

    /**
     * 根据ErrorCodeList.xlsx文件返回
     * List<SwiftTransferErrorInfo>
     */
    public static List<SwiftTransferErrorInfo> getMx2MtErrorCodes() {
        List<SwiftTransferErrorInfo> list = new ArrayList<>();
        InputStream resourceAsStream = SwiftTransferUtil.class.getResourceAsStream("/ErrorCodeList.xlsx");
        ExcelReader reader = ExcelUtil.getReader(resourceAsStream, "CBPR+");
        List<Map<String, Object>> content = reader.readAll();
        if (content.size() > 0) {
            for (int i=0; i<content.size(); i++) {
                Map<String, Object> contentMaps = content.get(i);
                String errorCode = (String)contentMaps.get("ErrorCode");
                String description = (String)contentMaps.get("Description");
                String errorType = (String)contentMaps.get("ErrorType");
                if (StringUtil.isNotEmpty(errorCode) && StringUtil.isNotEmpty(description)) {
                    SwiftTransferErrorInfo stErrorInfo = new SwiftTransferErrorInfo();
                    if (errorCode.indexOf("(") > -1) {
                        errorCode = errorCode.substring(0, errorCode.indexOf("("));
                    }
                    stErrorInfo.setErrorCode(errorCode.trim());
                    stErrorInfo.setDescription(description.trim());
                    stErrorInfo.setErrorType(errorType.trim());
                    list.add(stErrorInfo);
                }
            }
        }
        return list;
    }
}
