package com.brilliance.swift.util;

import org.apache.commons.io.FileUtils;
import org.dom4j.*;
import org.dom4j.io.SAXReader;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.util.*;

public class XmlUtil {

    public static String getRelativeName(File f, String s) {
        String MAIN = "cfg\\main";
        if (!f.getPath().contains(s) && !f.getPath().contains(MAIN)) {
            return f.getName();
        }
        String path = f.getPath();
        int index = path.indexOf(s);
        String relativePath = null;
        if (index == -1) {
            index = path.indexOf(MAIN);
        }
        relativePath = path.substring(index);
        relativePath = relativePath.replace("\\", "/");
        relativePath = relativePath.substring(s.length() + 1);
        if (relativePath.endsWith(".xml"))
            relativePath = relativePath.substring(0, relativePath.length() - 4);
        return relativePath;
    }

    public static String getXmlNode(String xmlstr, String path) throws DocumentException {
        return getXmlNodeValue(DocumentHelper.parseText(xmlstr), path);
    }

    /**
     * key = child element name
     * value = parent element name
     * @param doc
     * @return
     */
    public static Map<String, String> getParentElementMaps(Document doc) {
        Map<String, String> maps = new HashMap<>();
        Element rootElement = doc.getRootElement();
        String rootElementName = rootElement.getName();
        processElementMaps(maps, rootElement.elements(), rootElementName);
        return maps;
    }

    public static void processElementMaps(Map maps, List elements, String parentElementName) {
        if (elements != null && elements.size() > 0) {
            for (int i=0; i<elements.size(); i++) {
                Element element = (Element)elements.get(i);
                maps.put(element.getName(), parentElementName);
                processElementMaps(maps, element.elements(), parentElementName+"."+element.getName());
            }
        }
    }
    /**
     * 获取文档对象的指定路径的值
     *
     * @param doc
     * @param path
     * @return
     */
    @SuppressWarnings("unchecked")
    public static String getXmlNodeValue(Document doc, String path) {
        String[] paths = path.split("@");
        String[] layers = paths[0].split("\\.");
        Element rootElement = doc.getRootElement();
        Element curElement = rootElement;
        if (layers[0].equals(rootElement.getName())) {
            for (int i = 1; i < layers.length; i++) {
                int startIndex = layers[i].indexOf('(');
                if (-1 != startIndex) {
                    int endIndex = layers[i].indexOf(')');
                    int num = Integer.parseInt(layers[i].substring(startIndex + 1, endIndex));
                    layers[i] = layers[i].substring(0, startIndex);
                    List<Element> subElements = curElement.elements(layers[i]);
                    Element subElement = subElements.get(num);
                    curElement = subElement;
                } else {
                    Element subElement = curElement.element(layers[i]);
                    if (subElement == null) {
                        return null;
                    }
                    curElement = subElement;
                }
            }
            if (paths.length > 1)
                return curElement.attributeValue(paths[paths.length - 1]);
            return curElement.getText();
        }
        return null;
    }

    public static String getXmlValue(String xmlStr, String etag) {
        try {
            Document document = DocumentHelper.parseText(xmlStr);
            return getXmlNodeValue(document, etag);
        } catch (DocumentException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return null;
    }



    /**
     * 获取配置文件Document对象
     *
     * @param url
     * @return
     */
    public static Document getDocument(URL url) {
        SAXReader saxReader = new SAXReader();
        try {
            Document doc = saxReader.read(url);
            return doc;
        } catch (DocumentException e) {
            throw new RuntimeException("get document [" + url + "] error.", e);
        }
    }

    /**
     * 由路径和文件名拼出资源路径
     *
     * @param path
     * @param filename
     * @return
     */
    public static String getPath(String path, String filename) {
        if (!filename.endsWith(".xml")) {
            filename += ".xml";
        }
        return path + "/" + filename;
    }

    public static boolean isXpath(String type) {
        return (!StringUtil.isEmpty(type) && type.equalsIgnoreCase("xpath")) ? true : false;
    }

    public static int getChildrenCount(Branch document, String path, String type) {
        if (isXpath(type))
            return document.selectNodes(path).size();
        else {
            String[] paths = path.split("@");
            String[] layers = paths[0].split("\\.");
            Element rootElement = ((Document) document).getRootElement();
            Element curElement = rootElement;
            if (layers[0].equals(rootElement.getName())) {
                for (int i = 1; i < layers.length - 1; i++) {
                    int startIndex = layers[i].indexOf('(');
                    if (-1 != startIndex) {
                        int endIndex = layers[i].indexOf(')');
                        int num = Integer.parseInt(layers[i].substring(startIndex + 1, endIndex));
                        String mutiLayer = layers[i].substring(0, startIndex);
                        List<Element> subElements = curElement.elements(mutiLayer);
                        Element subElement = null;
                        int size = subElements.size();
                        if (num >= size) {
                            subElement = curElement.addElement(mutiLayer);
                        } else {
                            subElement = subElements.get(num);
                        }
                        curElement = subElement;
                    } else {
                        Element subElement = null;
                        if (layers[i].contains(":"))
                            subElement = curElement.element(layers[i].substring(layers[i].indexOf(':') + 1));
                        else
                            subElement = curElement.element(layers[i]);
                        if (subElement == null) {
                            subElement = curElement.addElement(layers[i]);
                        }
                        curElement = subElement;
                    }
                }
            }
            return curElement.elements(layers[layers.length - 1]).size();
        }

    }

    public static void main(String[] args) throws IOException, DocumentException {
       // File file = new File(System.getProperty("user.dir") + "\\src\\main\\resources\\swiftXml\\MxPacs00900109.xml");
       /* File file = new File("d:/test/test.xml");
        String xmlStr = FileUtils.readFileToString(file);
        Document document = DocumentHelper.parseText(xmlStr);
        String value = getXmlNodeValue(document, "Document.BkToCstmrStmt.GrpHdr.MsgId");
        System.out.println(value);*/

        /*File file = new File(System.getProperty("user.dir") + "\\src\\main\\resources\\swiftXml\\MxPacs00800109.xml");
        String xmlStr = FileUtils.readFileToString(file);
        Document document = DocumentHelper.parseText(xmlStr);
        String value = getXmlNodeValue(document, "Document.FIToFICstmrCdtTrf.CdtTrfTxInf.SttlmTmIndctn.DbtDtTm");
        System.out.println(value);*/

        File file = new File(System.getProperty("user.dir") + "\\src\\main\\resources\\swiftXml\\MxPacs00900109.xml");
        String xmlStr = FileUtils.readFileToString(file);
        Document document = DocumentHelper.parseText(xmlStr);
        Map<String, String> maps = getParentElementMaps(document);
        Set<String> sets = maps.keySet();
        Iterator<String> keys = sets.iterator();
        boolean flag = false;
        for (; keys.hasNext(); ) {
            String key = keys.next();
            String value = maps.get(key);
            String fullPath = value + "." + key;
            if (fullPath.indexOf("UndrlygCstmrCdtTrf") > -1
                && StringUtil.isNotEmpty(getXmlNodeValue(document, fullPath))){
                flag = true;
                break;
            }
        }
        System.out.println(flag);
    }
}
