package com.brilliance.mt2mx.pacs008001;

import com.alibaba.fastjson.JSONObject;
import com.brilliance.swift.SwiftTransfer;
import com.brilliance.swift.util.DateUtil;
import com.brilliance.swift.util.StringUtil;
import com.brilliance.swift.util.XmlUtil;
import com.brilliance.swift.vo.common.CcyFormatAmount;
import com.brilliance.swift.vo.common.ChargeInfo;
import org.apache.commons.io.FileUtils;
import org.dom4j.Document;
import org.dom4j.DocumentHelper;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.File;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Test {

    static String appHdr = "Envelope";
    static String grpHdr = "Envelope.Document.FIToFICstmrCdtTrf";
    static String bodyHdr = "Envelope.Document.FIToFICstmrCdtTrf";
    static String defaultFormate = "yyyy-MM-dd HH:mm:ss,SSS";

    public static Object getXmlPathValue(Document document, String xmlPath) throws DatatypeConfigurationException, IOException {
        xmlPath = xmlPath.replace("#APP", appHdr).replace("#GRP", grpHdr).replace("#BODY", bodyHdr);
        Object value = null;
        if (xmlPath.indexOf("*") > -1) { //出现多个值
            String beginPath = xmlPath.substring(0, xmlPath.indexOf("*"));
            String endPath = xmlPath.substring(xmlPath.indexOf("*")+1);
            String type = "String";
            if (endPath.indexOf("&") > -1) {
                type = endPath.substring(endPath.indexOf("&")+1);
                endPath = endPath.substring(0, endPath.indexOf("&"));
            }
            int count = XmlUtil.getChildrenCount(document, beginPath, null);
            if (count > 0) {
                if ("String".equalsIgnoreCase(type)) {
                    List<String> list = new ArrayList<>();
                    for (int i=0; i<count; i++) {
                        String xmlValue = XmlUtil.getXmlNodeValue(document, beginPath+"("+i+")."+endPath);
                        list.add(xmlValue);
                    }
                    value = list;
                } else if ("BigDecimal".equalsIgnoreCase(type)) {
                    List<BigDecimal> list = new ArrayList<>();
                    for (int i=0; i<count; i++) {
                        String xmlValue = XmlUtil.getXmlNodeValue(document, beginPath+"("+i+")."+endPath);
                        list.add(new BigDecimal(xmlValue));
                    }
                    value = list;
                }
            }
        } else if (xmlPath.indexOf("&") > -1) { //数据类型
            String type = xmlPath.substring(xmlPath.indexOf("&")+1);
            xmlPath = xmlPath.substring(0, xmlPath.indexOf("&"));
            String xmlValue = XmlUtil.getXmlNodeValue(document, xmlPath);
            if ("DATE".equalsIgnoreCase(type) && StringUtil.isNotEmpty(xmlValue)) {
                XMLGregorianCalendar dtTm = DatatypeFactory.newInstance().newXMLGregorianCalendar(xmlValue);
                value = DateUtil.format(dtTm.toGregorianCalendar().getTime(), defaultFormate);
            } else if ("BigDecimal".equalsIgnoreCase(type) && StringUtil.isNotEmpty(xmlValue)) {
                value = new BigDecimal(xmlValue);
            } else if ("List<String>".equalsIgnoreCase(type) && StringUtil.isNotEmpty(xmlValue)) {
                int count = XmlUtil.getChildrenCount(document, xmlPath, null);
                if (count > 0) {
                    List<String> list = new ArrayList<>();
                    for (int i=0; i<count; i++) {
                        xmlValue = XmlUtil.getXmlNodeValue(document, xmlPath+"("+i+")");
                        list.add(xmlValue);
                    }
                    value = list;
                }
            }
        } else {
            value = XmlUtil.getXmlNodeValue(document, xmlPath);
        }
        return value;
    }

    public static void main(String[] args) throws Exception {
        /*String mt103 = SwiftTransfer.mt2Mx(
                new File(System.getProperty("user.dir")+"\\swiftCore\\src\\main\\resources\\swiftTxt\\Mt103.txt"),
                "d:/test/pacs00800109.xml", null);
        System.out.println(mt103);*/
        String xmlStr = FileUtils.readFileToString(new File(System.getProperty("user.dir")+"\\swiftCore\\src\\main\\resources\\swiftXml\\MxPacs00800109.xml"));
        Document document = DocumentHelper.parseText(xmlStr);

        Map<String, Object> maps = new HashMap<>();
        Map<String, Object> swiftHeader = new HashMap<>();
        swiftHeader.put("messageType", "pacs.008.001");
        swiftHeader.put("version", "09");
        maps.put("swiftHeader", swiftHeader);
        File propertyFile = new File(System.getProperty("user.dir")+"\\swiftCore\\src\\main\\resources\\template\\mx2swiftdto\\pacs008001.Properties");
        List<String> properties = FileUtils.readLines(propertyFile);
        if (properties.size() > 0) {
            for (String property : properties) {
                if (property.startsWith("#")) {
                    continue;//过滤注释
                }
                String[] strArr = property.split("=");
                if (strArr.length != 2) {
                    continue;//过滤掉不符合规则的配置
                }
                String key = strArr[0];
                String xmlPath = strArr[1];
                Object xmlValue = getXmlPathValue(document, xmlPath);
                if (xmlValue == null) continue;
                String[] keys = key.split("\\.");
                if (keys.length == 1) {
                    maps.put(keys[0], xmlValue); //如果只有一个节点，直接put值
                } else { //如果节点值超过1个，先赋值第一个节点，再循环赋值，最后一个节点直接put值。
                    Map<String, Object> keyMap = null;
                    if (maps.containsKey(keys[0])) {
                        keyMap = (Map<String, Object>)maps.get(keys[0]);
                    } else {
                        keyMap = new HashMap<>();
                        maps.put(keys[0], keyMap);
                    }
                    for (int i=1; i<keys.length; i++) {
                        if (i == keys.length-1) {
                            keyMap.put(keys[i], xmlValue);
                            break;
                        }
                        if (!keyMap.containsKey(keys[i])) {
                            keyMap.put(keys[i], new HashMap<>());
                        }
                        keyMap = (Map<String, Object>)keyMap.get(keys[i]);
                    }
                }
            }
        }
        List<ChargeInfo> chargeInfos = new ArrayList<>();
        CcyFormatAmount ccyFormatAmount = new CcyFormatAmount();
        ccyFormatAmount.setCcy("USD");
        ccyFormatAmount.setAmt(new BigDecimal("13.45"));
        ChargeInfo chargeInfo = new ChargeInfo();
        chargeInfo.setAmt(ccyFormatAmount);
        CcyFormatAmount ccyFormatAmount1 = new CcyFormatAmount();
        ccyFormatAmount1.setCcy("USD");
        ccyFormatAmount1.setAmt(new BigDecimal("23.56"));
        ChargeInfo chargeInfo1 = new ChargeInfo();
        chargeInfo1.setAmt(ccyFormatAmount1);
        chargeInfos.add(chargeInfo);
        chargeInfos.add(chargeInfo1);
        maps.put("chargeInfos", chargeInfos);
        /*Map<String, Object> resultMap = new HashMap<>();
        Map<String, Object> txnRef = new HashMap<>();
        txnRef.put("instructionId", "GTBEXO12345");
        txnRef.put("endToEndId", "GTBEXO12345");
        txnRef.put("uetr", "8a562c67-ca16-48ba-b074-65581be6f001");
        resultMap.put("txnRef", txnRef);
        Map<String, Object> swiftHeader = new HashMap<>();
        swiftHeader.put("messageType", "pacs.008.001");
        swiftHeader.put("version", "09");
        resultMap.put("swiftHeader", swiftHeader);*/
        //SwiftDto swiftDto = SwiftDto.fromJson(new JSONObject(maps).toJSONString());
        System.out.println(new JSONObject(maps).toJSONString());
        String mt = SwiftTransfer.swiftDto2Mt(new JSONObject(maps).toJSONString(), null, null);
        System.out.println(mt);
    }
}
